from __future__ import absolute_import
from __future__ import division

from pwn import *
from pwnlib.commandline import common

from mako.lookup import TemplateLookup, Template

parser = common.parser_commands.add_parser(
    'template',
    help = 'Generate an exploit template',
    description = 'Generate an exploit template. If no arguments are given, '
                    'the current directory is searched for an executable binary and ' 
                    'libc. If only one binary is found, it is assumed to be the '
                    'challenge binary.'
)

# change path to hardcoded one when building the documentation
printable_data_path = "pwnlib/data" if 'sphinx' in sys.modules else pwnlib.data.path

parser.add_argument('exe', nargs='?', help='Target binary. If not given, the current directory is searched for an executable binary.')
parser.add_argument('--host', help='Remote host / SSH server')
parser.add_argument('--port', help='Remote port / SSH port', type=int)
parser.add_argument('--user', help='SSH Username')
parser.add_argument('--pass', '--password', help='SSH Password', dest='password')
parser.add_argument('--libc', help='Path to libc binary to use. If not given, the current directory is searched for a libc binary.')
parser.add_argument('--path', help='Remote path of file on SSH server')
parser.add_argument('--quiet', help='Less verbose template comments', action='store_true')
parser.add_argument('--color', help='Print the output in color', choices=['never', 'always', 'auto'], default='auto')
parser.add_argument('--template', help='Path to a custom template. Tries to use \'~/.config/pwntools/templates/pwnup.mako\', if it exists. '
                                   'Check \'%s\' for the default template shipped with pwntools.' % 
                                        os.path.join(printable_data_path, "templates", "pwnup.mako"))
parser.add_argument('--no-auto', help='Do not automatically detect missing binaries', action='store_false', dest='auto')

def detect_missing_binaries(args):
    log.info("Automatically detecting challenge binaries...")
    # look for challenge binary, libc, and ld in current directory
    exe, libc, ld = args.exe, args.libc, None
    other_files = []
    for filename in os.listdir():
        if not os.path.isfile(filename):
            continue
        if not libc and ('libc-' in filename or 'libc.' in filename):
            libc = filename
        elif not ld and 'ld-' in filename:
            ld = filename
        else:
            if os.access(filename, os.X_OK):
                other_files.append(filename)
    if not exe:
        if len(other_files) == 1:
            exe = other_files[0]
        elif len(other_files) > 1:
            log.warning("Failed to find challenge binary. There are multiple binaries in the current directory: %s", other_files)

    if exe != args.exe:
        log.success("Found challenge binary %r", exe)
    if libc != args.libc:
        log.success("Found libc binary %r", libc)
    return exe, libc

def main(args):

    lookup = TemplateLookup(
        directories      = [
            os.path.expanduser('~/.config/pwntools/templates/'),
            os.path.join(pwnlib.data.path, 'templates')
        ],
        module_directory = None
    )

    # For the SSH scenario, check that the binary is at the
    # same path on the remote host.
    if args.user:
        if not (args.path or args.exe):
            log.error("Must specify --path or a exe")

        with ssh(args.user, args.host, args.port or 22, args.password or None) as s:
            try:
                remote_file = args.path or args.exe
                s.download(remote_file)
            except Exception:
                log.warning("Could not download file %r, opening a shell", remote_file)
                s.interactive()
                return

        if not args.exe:
            args.exe = os.path.basename(args.path)

    if args.auto and (args.exe is None or args.libc is None):
        args.exe, args.libc = detect_missing_binaries(args)
    
    if args.template:
        template = Template(filename=args.template) # Failing on invalid file is ok
    else:
        template = lookup.get_template('pwnup.mako')
    
    output = template.render(args.exe,
                             args.host,
                             args.port,
                             args.user,
                             args.password,
                             args.libc,
                             args.path,
                             args.quiet)

    # Fix Mako formatting bs
    output = re.sub('\n\n\n', '\n\n', output)

    # Colorize the output if it's a TTY
    if args.color == 'always' or (args.color == 'auto' and sys.stdout.isatty()):
        from pygments import highlight
        from pygments.formatters import TerminalFormatter
        from pygments.lexers.python import PythonLexer
        output = highlight(output, PythonLexer(), TerminalFormatter())

    print(output)

    # If redirected to a file, make the resulting script executable
    if not sys.stdout.isatty():
        try: os.fchmod(sys.stdout.fileno(), 0o700)
        except OSError: pass

if __name__ == '__main__':
    pwnlib.commandline.common.main(__file__, main)
    



from pwnlib.constants.constant import Constant
__NR_Linux = Constant('__NR_Linux',1024)
__NR_ni_syscall = Constant('__NR_ni_syscall',(1024 + 0))
__NR_exit = Constant('__NR_exit',(1024 + 1))
__NR_read = Constant('__NR_read',(1024 + 2))
__NR_write = Constant('__NR_write',(1024 + 3))
__NR_open = Constant('__NR_open',(1024 + 4))
__NR_close = Constant('__NR_close',(1024 + 5))
__NR_creat = Constant('__NR_creat',(1024 + 6))
__NR_link = Constant('__NR_link',(1024 + 7))
__NR_unlink = Constant('__NR_unlink',(1024 + 8))
__NR_execve = Constant('__NR_execve',(1024 + 9))
__NR_chdir = Constant('__NR_chdir',(1024 + 10))
__NR_fchdir = Constant('__NR_fchdir',(1024 + 11))
__NR_utimes = Constant('__NR_utimes',(1024 + 12))
__NR_mknod = Constant('__NR_mknod',(1024 + 13))
__NR_chmod = Constant('__NR_chmod',(1024 + 14))
__NR_chown = Constant('__NR_chown',(1024 + 15))
__NR_lseek = Constant('__NR_lseek',(1024 + 16))
__NR_getpid = Constant('__NR_getpid',(1024 + 17))
__NR_getppid = Constant('__NR_getppid',(1024 + 18))
__NR_mount = Constant('__NR_mount',(1024 + 19))
__NR_umount2 = Constant('__NR_umount2',(1024 + 20))
__NR_setuid = Constant('__NR_setuid',(1024 + 21))
__NR_getuid = Constant('__NR_getuid',(1024 + 22))
__NR_geteuid = Constant('__NR_geteuid',(1024 + 23))
__NR_ptrace = Constant('__NR_ptrace',(1024 + 24))
__NR_access = Constant('__NR_access',(1024 + 25))
__NR_sync = Constant('__NR_sync',(1024 + 26))
__NR_fsync = Constant('__NR_fsync',(1024 + 27))
__NR_fdatasync = Constant('__NR_fdatasync',(1024 + 28))
__NR_kill = Constant('__NR_kill',(1024 + 29))
__NR_rename = Constant('__NR_rename',(1024 + 30))
__NR_mkdir = Constant('__NR_mkdir',(1024 + 31))
__NR_rmdir = Constant('__NR_rmdir',(1024 + 32))
__NR_dup = Constant('__NR_dup',(1024 + 33))
__NR_pipe = Constant('__NR_pipe',(1024 + 34))
__NR_times = Constant('__NR_times',(1024 + 35))
__NR_brk = Constant('__NR_brk',(1024 + 36))
__NR_setgid = Constant('__NR_setgid',(1024 + 37))
__NR_getgid = Constant('__NR_getgid',(1024 + 38))
__NR_getegid = Constant('__NR_getegid',(1024 + 39))
__NR_acct = Constant('__NR_acct',(1024 + 40))
__NR_ioctl = Constant('__NR_ioctl',(1024 + 41))
__NR_fcntl = Constant('__NR_fcntl',(1024 + 42))
__NR_umask = Constant('__NR_umask',(1024 + 43))
__NR_chroot = Constant('__NR_chroot',(1024 + 44))
__NR_ustat = Constant('__NR_ustat',(1024 + 45))
__NR_dup2 = Constant('__NR_dup2',(1024 + 46))
__NR_setreuid = Constant('__NR_setreuid',(1024 + 47))
__NR_setregid = Constant('__NR_setregid',(1024 + 48))
__NR_getresuid = Constant('__NR_getresuid',(1024 + 49))
__NR_setresuid = Constant('__NR_setresuid',(1024 + 50))
__NR_getresgid = Constant('__NR_getresgid',(1024 + 51))
__NR_setresgid = Constant('__NR_setresgid',(1024 + 52))
__NR_getgroups = Constant('__NR_getgroups',(1024 + 53))
__NR_setgroups = Constant('__NR_setgroups',(1024 + 54))
__NR_getpgid = Constant('__NR_getpgid',(1024 + 55))
__NR_setpgid = Constant('__NR_setpgid',(1024 + 56))
__NR_setsid = Constant('__NR_setsid',(1024 + 57))
__NR_getsid = Constant('__NR_getsid',(1024 + 58))
__NR_sethostname = Constant('__NR_sethostname',(1024 + 59))
__NR_setrlimit = Constant('__NR_setrlimit',(1024 + 60))
__NR_getrlimit = Constant('__NR_getrlimit',(1024 + 61))
__NR_getrusage = Constant('__NR_getrusage',(1024 + 62))
__NR_gettimeofday = Constant('__NR_gettimeofday',(1024 + 63))
__NR_settimeofday = Constant('__NR_settimeofday',(1024 + 64))
__NR_select = Constant('__NR_select',(1024 + 65))
__NR_poll = Constant('__NR_poll',(1024 + 66))
__NR_symlink = Constant('__NR_symlink',(1024 + 67))
__NR_readlink = Constant('__NR_readlink',(1024 + 68))
__NR_uselib = Constant('__NR_uselib',(1024 + 69))
__NR_swapon = Constant('__NR_swapon',(1024 + 70))
__NR_swapoff = Constant('__NR_swapoff',(1024 + 71))
__NR_reboot = Constant('__NR_reboot',(1024 + 72))
__NR_truncate = Constant('__NR_truncate',(1024 + 73))
__NR_ftruncate = Constant('__NR_ftruncate',(1024 + 74))
__NR_fchmod = Constant('__NR_fchmod',(1024 + 75))
__NR_fchown = Constant('__NR_fchown',(1024 + 76))
__NR_getpriority = Constant('__NR_getpriority',(1024 + 77))
__NR_setpriority = Constant('__NR_setpriority',(1024 + 78))
__NR_statfs = Constant('__NR_statfs',(1024 + 79))
__NR_fstatfs = Constant('__NR_fstatfs',(1024 + 80))
__NR_gettid = Constant('__NR_gettid',(1024 + 81))
__NR_semget = Constant('__NR_semget',(1024 + 82))
__NR_semop = Constant('__NR_semop',(1024 + 83))
__NR_semctl = Constant('__NR_semctl',(1024 + 84))
__NR_msgget = Constant('__NR_msgget',(1024 + 85))
__NR_msgsnd = Constant('__NR_msgsnd',(1024 + 86))
__NR_msgrcv = Constant('__NR_msgrcv',(1024 + 87))
__NR_msgctl = Constant('__NR_msgctl',(1024 + 88))
__NR_shmget = Constant('__NR_shmget',(1024 + 89))
__NR_shmat = Constant('__NR_shmat',(1024 + 90))
__NR_shmdt = Constant('__NR_shmdt',(1024 + 91))
__NR_shmctl = Constant('__NR_shmctl',(1024 + 92))
__NR_syslog = Constant('__NR_syslog',(1024 + 93))
__NR_setitimer = Constant('__NR_setitimer',(1024 + 94))
__NR_getitimer = Constant('__NR_getitimer',(1024 + 95))
__NR_vhangup = Constant('__NR_vhangup',(1024 + 99))
__NR_lchown = Constant('__NR_lchown',(1024 + 100))
__NR_remap_file_pages = Constant('__NR_remap_file_pages',(1024 + 101))
__NR_wait4 = Constant('__NR_wait4',(1024 + 102))
__NR_sysinfo = Constant('__NR_sysinfo',(1024 + 103))
__NR_clone = Constant('__NR_clone',(1024 + 104))
__NR_setdomainname = Constant('__NR_setdomainname',(1024 + 105))
__NR_uname = Constant('__NR_uname',(1024 + 106))
__NR_adjtimex = Constant('__NR_adjtimex',(1024 + 107))
__NR_init_module = Constant('__NR_init_module',(1024 + 109))
__NR_delete_module = Constant('__NR_delete_module',(1024 + 110))
__NR_quotactl = Constant('__NR_quotactl',(1024 + 113))
__NR_bdflush = Constant('__NR_bdflush',(1024 + 114))
__NR_sysfs = Constant('__NR_sysfs',(1024 + 115))
__NR_personality = Constant('__NR_personality',(1024 + 116))
__NR_afs_syscall = Constant('__NR_afs_syscall',(1024 + 117))
__NR_setfsuid = Constant('__NR_setfsuid',(1024 + 118))
__NR_setfsgid = Constant('__NR_setfsgid',(1024 + 119))
__NR_getdents = Constant('__NR_getdents',(1024 + 120))
__NR_flock = Constant('__NR_flock',(1024 + 121))
__NR_readv = Constant('__NR_readv',(1024 + 122))
__NR_writev = Constant('__NR_writev',(1024 + 123))
__NR_pread64 = Constant('__NR_pread64',(1024 + 124))
__NR_pwrite64 = Constant('__NR_pwrite64',(1024 + 125))
__NR__sysctl = Constant('__NR__sysctl',(1024 + 126))
__NR_mmap = Constant('__NR_mmap',(1024 + 127))
__NR_munmap = Constant('__NR_munmap',(1024 + 128))
__NR_mlock = Constant('__NR_mlock',(1024 + 129))
__NR_mlockall = Constant('__NR_mlockall',(1024 + 130))
__NR_mprotect = Constant('__NR_mprotect',(1024 + 131))
__NR_mremap = Constant('__NR_mremap',(1024 + 132))
__NR_msync = Constant('__NR_msync',(1024 + 133))
__NR_munlock = Constant('__NR_munlock',(1024 + 134))
__NR_munlockall = Constant('__NR_munlockall',(1024 + 135))
__NR_sched_getparam = Constant('__NR_sched_getparam',(1024 + 136))
__NR_sched_setparam = Constant('__NR_sched_setparam',(1024 + 137))
__NR_sched_getscheduler = Constant('__NR_sched_getscheduler',(1024 + 138))
__NR_sched_setscheduler = Constant('__NR_sched_setscheduler',(1024 + 139))
__NR_sched_yield = Constant('__NR_sched_yield',(1024 + 140))
__NR_sched_get_priority_max = Constant('__NR_sched_get_priority_max',(1024 + 141))
__NR_sched_get_priority_min = Constant('__NR_sched_get_priority_min',(1024 + 142))
__NR_sched_rr_get_interval = Constant('__NR_sched_rr_get_interval',(1024 + 143))
__NR_nanosleep = Constant('__NR_nanosleep',(1024 + 144))
__NR_nfsservctl = Constant('__NR_nfsservctl',(1024 + 145))
__NR_prctl = Constant('__NR_prctl',(1024 + 146))
__NR_old_getpagesize = Constant('__NR_old_getpagesize',(1024 + 147))
__NR_mmap2 = Constant('__NR_mmap2',(1024 + 148))
__NR_pciconfig_read = Constant('__NR_pciconfig_read',(1024 + 149))
__NR_pciconfig_write = Constant('__NR_pciconfig_write',(1024 + 150))
__NR_perfmonctl = Constant('__NR_perfmonctl',(1024 + 151))
__NR_sigaltstack = Constant('__NR_sigaltstack',(1024 + 152))
__NR_rt_sigaction = Constant('__NR_rt_sigaction',(1024 + 153))
__NR_rt_sigpending = Constant('__NR_rt_sigpending',(1024 + 154))
__NR_rt_sigprocmask = Constant('__NR_rt_sigprocmask',(1024 + 155))
__NR_rt_sigqueueinfo = Constant('__NR_rt_sigqueueinfo',(1024 + 156))
__NR_rt_sigreturn = Constant('__NR_rt_sigreturn',(1024 + 157))
__NR_rt_sigsuspend = Constant('__NR_rt_sigsuspend',(1024 + 158))
__NR_rt_sigtimedwait = Constant('__NR_rt_sigtimedwait',(1024 + 159))
__NR_getcwd = Constant('__NR_getcwd',(1024 + 160))
__NR_capget = Constant('__NR_capget',(1024 + 161))
__NR_capset = Constant('__NR_capset',(1024 + 162))
__NR_sendfile = Constant('__NR_sendfile',(1024 + 163))
__NR_getpmsg = Constant('__NR_getpmsg',(1024 + 164))
__NR_putpmsg = Constant('__NR_putpmsg',(1024 + 165))
__NR_socket = Constant('__NR_socket',(1024 + 166))
__NR_bind = Constant('__NR_bind',(1024 + 167))
__NR_connect = Constant('__NR_connect',(1024 + 168))
__NR_listen = Constant('__NR_listen',(1024 + 169))
__NR_accept = Constant('__NR_accept',(1024 + 170))
__NR_getsockname = Constant('__NR_getsockname',(1024 + 171))
__NR_getpeername = Constant('__NR_getpeername',(1024 + 172))
__NR_socketpair = Constant('__NR_socketpair',(1024 + 173))
__NR_send = Constant('__NR_send',(1024 + 174))
__NR_sendto = Constant('__NR_sendto',(1024 + 175))
__NR_recv = Constant('__NR_recv',(1024 + 176))
__NR_recvfrom = Constant('__NR_recvfrom',(1024 + 177))
__NR_shutdown = Constant('__NR_shutdown',(1024 + 178))
__NR_setsockopt = Constant('__NR_setsockopt',(1024 + 179))
__NR_getsockopt = Constant('__NR_getsockopt',(1024 + 180))
__NR_sendmsg = Constant('__NR_sendmsg',(1024 + 181))
__NR_recvmsg = Constant('__NR_recvmsg',(1024 + 182))
__NR_pivot_root = Constant('__NR_pivot_root',(1024 + 183))
__NR_mincore = Constant('__NR_mincore',(1024 + 184))
__NR_madvise = Constant('__NR_madvise',(1024 + 185))
__NR_stat = Constant('__NR_stat',(1024 + 186))
__NR_lstat = Constant('__NR_lstat',(1024 + 187))
__NR_fstat = Constant('__NR_fstat',(1024 + 188))
__NR_clone2 = Constant('__NR_clone2',(1024 + 189))
__NR_getdents64 = Constant('__NR_getdents64',(1024 + 190))
__NR_getunwind = Constant('__NR_getunwind',(1024 + 191))
__NR_readahead = Constant('__NR_readahead',(1024 + 192))
__NR_setxattr = Constant('__NR_setxattr',(1024 + 193))
__NR_lsetxattr = Constant('__NR_lsetxattr',(1024 + 194))
__NR_fsetxattr = Constant('__NR_fsetxattr',(1024 + 195))
__NR_getxattr = Constant('__NR_getxattr',(1024 + 196))
__NR_lgetxattr = Constant('__NR_lgetxattr',(1024 + 197))
__NR_fgetxattr = Constant('__NR_fgetxattr',(1024 + 198))
__NR_listxattr = Constant('__NR_listxattr',(1024 + 199))
__NR_llistxattr = Constant('__NR_llistxattr',(1024 + 200))
__NR_flistxattr = Constant('__NR_flistxattr',(1024 + 201))
__NR_removexattr = Constant('__NR_removexattr',(1024 + 202))
__NR_lremovexattr = Constant('__NR_lremovexattr',(1024 + 203))
__NR_fremovexattr = Constant('__NR_fremovexattr',(1024 + 204))
__NR_tkill = Constant('__NR_tkill',(1024 + 205))
__NR_futex = Constant('__NR_futex',(1024 + 206))
__NR_sched_setaffinity = Constant('__NR_sched_setaffinity',(1024 + 207))
__NR_sched_getaffinity = Constant('__NR_sched_getaffinity',(1024 + 208))
__NR_set_tid_address = Constant('__NR_set_tid_address',(1024 + 209))
__NR_fadvise64 = Constant('__NR_fadvise64',(1024 + 210))
__NR_tgkill = Constant('__NR_tgkill',(1024 + 211))
__NR_exit_group = Constant('__NR_exit_group',(1024 + 212))
__NR_lookup_dcookie = Constant('__NR_lookup_dcookie',(1024 + 213))
__NR_io_setup = Constant('__NR_io_setup',(1024 + 214))
__NR_io_destroy = Constant('__NR_io_destroy',(1024 + 215))
__NR_io_getevents = Constant('__NR_io_getevents',(1024 + 216))
__NR_io_submit = Constant('__NR_io_submit',(1024 + 217))
__NR_io_cancel = Constant('__NR_io_cancel',(1024 + 218))
__NR_epoll_create = Constant('__NR_epoll_create',(1024 + 219))
__NR_epoll_ctl = Constant('__NR_epoll_ctl',(1024 + 220))
__NR_epoll_wait = Constant('__NR_epoll_wait',(1024 + 221))
__NR_restart_syscall = Constant('__NR_restart_syscall',(1024 + 222))
__NR_semtimedop = Constant('__NR_semtimedop',(1024 + 223))
__NR_timer_create = Constant('__NR_timer_create',(1024 + 224))
__NR_timer_settime = Constant('__NR_timer_settime',(1024 + 225))
__NR_timer_gettime = Constant('__NR_timer_gettime',(1024 + 226))
__NR_timer_getoverrun = Constant('__NR_timer_getoverrun',(1024 + 227))
__NR_timer_delete = Constant('__NR_timer_delete',(1024 + 228))
__NR_clock_settime = Constant('__NR_clock_settime',(1024 + 229))
__NR_clock_gettime = Constant('__NR_clock_gettime',(1024 + 230))
__NR_clock_getres = Constant('__NR_clock_getres',(1024 + 231))
__NR_clock_nanosleep = Constant('__NR_clock_nanosleep',(1024 + 232))
__NR_fstatfs64 = Constant('__NR_fstatfs64',(1024 + 233))
__NR_statfs64 = Constant('__NR_statfs64',(1024 + 234))
__NR_mbind = Constant('__NR_mbind',(1024 + 235))
__NR_get_mempolicy = Constant('__NR_get_mempolicy',(1024 + 236))
__NR_set_mempolicy = Constant('__NR_set_mempolicy',(1024 + 237))
__NR_mq_open = Constant('__NR_mq_open',(1024 + 238))
__NR_mq_unlink = Constant('__NR_mq_unlink',(1024 + 239))
__NR_mq_timedsend = Constant('__NR_mq_timedsend',(1024 + 240))
__NR_mq_timedreceive = Constant('__NR_mq_timedreceive',(1024 + 241))
__NR_mq_notify = Constant('__NR_mq_notify',(1024 + 242))
__NR_mq_getsetattr = Constant('__NR_mq_getsetattr',(1024 + 243))
__NR_kexec_load = Constant('__NR_kexec_load',(1024 + 244))
__NR_vserver = Constant('__NR_vserver',(1024 + 245))
__NR_waitid = Constant('__NR_waitid',(1024 + 246))
__NR_add_key = Constant('__NR_add_key',(1024 + 247))
__NR_request_key = Constant('__NR_request_key',(1024 + 248))
__NR_keyctl = Constant('__NR_keyctl',(1024 + 249))
__NR_ioprio_set = Constant('__NR_ioprio_set',(1024 + 250))
__NR_ioprio_get = Constant('__NR_ioprio_get',(1024 + 251))
__NR_move_pages = Constant('__NR_move_pages',(1024 + 252))
__NR_inotify_init = Constant('__NR_inotify_init',(1024 + 253))
__NR_inotify_add_watch = Constant('__NR_inotify_add_watch',(1024 + 254))
__NR_inotify_rm_watch = Constant('__NR_inotify_rm_watch',(1024 + 255))
__NR_migrate_pages = Constant('__NR_migrate_pages',(1024 + 256))
__NR_openat = Constant('__NR_openat',(1024 + 257))
__NR_mkdirat = Constant('__NR_mkdirat',(1024 + 258))
__NR_mknodat = Constant('__NR_mknodat',(1024 + 259))
__NR_fchownat = Constant('__NR_fchownat',(1024 + 260))
__NR_futimesat = Constant('__NR_futimesat',(1024 + 261))
__NR_newfstatat = Constant('__NR_newfstatat',(1024 + 262))
__NR_unlinkat = Constant('__NR_unlinkat',(1024 + 263))
__NR_renameat = Constant('__NR_renameat',(1024 + 264))
__NR_linkat = Constant('__NR_linkat',(1024 + 265))
__NR_symlinkat = Constant('__NR_symlinkat',(1024 + 266))
__NR_readlinkat = Constant('__NR_readlinkat',(1024 + 267))
__NR_fchmodat = Constant('__NR_fchmodat',(1024 + 268))
__NR_faccessat = Constant('__NR_faccessat',(1024 + 269))
__NR_pselect6 = Constant('__NR_pselect6',(1024 + 270))
__NR_ppoll = Constant('__NR_ppoll',(1024 + 271))
__NR_unshare = Constant('__NR_unshare',(1024 + 272))
__NR_splice = Constant('__NR_splice',(1024 + 273))
__NR_set_robust_list = Constant('__NR_set_robust_list',(1024 + 274))
__NR_get_robust_list = Constant('__NR_get_robust_list',(1024 + 275))
__NR_sync_file_range = Constant('__NR_sync_file_range',(1024 + 276))
__NR_tee = Constant('__NR_tee',(1024 + 277))
__NR_vmsplice = Constant('__NR_vmsplice',(1024 + 278))
__NR_fallocate = Constant('__NR_fallocate',(1024 + 279))
__NR_getcpu = Constant('__NR_getcpu',(1024 + 280))
__NR_epoll_pwait = Constant('__NR_epoll_pwait',(1024 + 281))
__NR_utimensat = Constant('__NR_utimensat',(1024 + 282))
__NR_signalfd = Constant('__NR_signalfd',(1024 + 283))
__NR_timerfd = Constant('__NR_timerfd',(1024 + 284))
__NR_eventfd = Constant('__NR_eventfd',(1024 + 285))
__NR_timerfd_create = Constant('__NR_timerfd_create',(1024 + 286))
__NR_timerfd_settime = Constant('__NR_timerfd_settime',(1024 + 287))
__NR_timerfd_gettime = Constant('__NR_timerfd_gettime',(1024 + 288))
__NR_signalfd4 = Constant('__NR_signalfd4',(1024 + 289))
__NR_eventfd2 = Constant('__NR_eventfd2',(1024 + 290))
__NR_epoll_create1 = Constant('__NR_epoll_create1',(1024 + 291))
__NR_dup3 = Constant('__NR_dup3',(1024 + 292))
__NR_pipe2 = Constant('__NR_pipe2',(1024 + 293))
__NR_inotify_init1 = Constant('__NR_inotify_init1',(1024 + 294))
__NR_preadv = Constant('__NR_preadv',(1024 + 295))
__NR_pwritev = Constant('__NR_pwritev',(1024 + 296))
__NR_rt_tgsigqueueinfo = Constant('__NR_rt_tgsigqueueinfo',(1024 + 297))
__NR_recvmmsg = Constant('__NR_recvmmsg',(1024 + 298))
__NR_fanotify_init = Constant('__NR_fanotify_init',(1024 + 299))
__NR_fanotify_mark = Constant('__NR_fanotify_mark',(1024 + 300))
__NR_prlimit64 = Constant('__NR_prlimit64',(1024 + 301))
__NR_name_to_handle_at = Constant('__NR_name_to_handle_at',(1024 + 302))
__NR_open_by_handle_at = Constant('__NR_open_by_handle_at',(1024 + 303))
__NR_clock_adjtime = Constant('__NR_clock_adjtime',(1024 + 304))
__NR_syncfs = Constant('__NR_syncfs',(1024 + 305))
__NR_setns = Constant('__NR_setns',(1024 + 306))
__NR_sendmmsg = Constant('__NR_sendmmsg',(1024 + 307))
__NR_process_vm_readv = Constant('__NR_process_vm_readv',(1024 + 308))
__NR_process_vm_writev = Constant('__NR_process_vm_writev',(1024 + 309))
__NR_accept4 = Constant('__NR_accept4',(1024 + 310))
__NR_finit_module = Constant('__NR_finit_module',(1024 + 311))
__NR_sched_setattr = Constant('__NR_sched_setattr',(1024 + 312))
__NR_sched_getattr = Constant('__NR_sched_getattr',(1024 + 313))
__NR_renameat2 = Constant('__NR_renameat2',(1024 + 314))
__NR_getrandom = Constant('__NR_getrandom',(1024 + 315))
__NR_memfd_create = Constant('__NR_memfd_create',(1024 + 316))
__NR_bpf = Constant('__NR_bpf',(1024 + 317))
__NR_execveat = Constant('__NR_execveat',(1024 + 318))
__NR_userfaultfd = Constant('__NR_userfaultfd',(1024 + 319))
__NR_membarrier = Constant('__NR_membarrier',(1024 + 320))
__NR_kcmp = Constant('__NR_kcmp',(1024 + 321))
__NR_mlock2 = Constant('__NR_mlock2',(1024 + 322))
__NR_copy_file_range = Constant('__NR_copy_file_range',(1024 + 323))
__NR_preadv2 = Constant('__NR_preadv2',(1024 + 324))
__NR_pwritev2 = Constant('__NR_pwritev2',(1024 + 325))
__NR_statx = Constant('__NR_statx',(1024 + 326))
__NR_io_pgetevents = Constant('__NR_io_pgetevents',(1024 + 327))
__NR_perf_event_open = Constant('__NR_perf_event_open',(1024 + 328))
__NR_seccomp = Constant('__NR_seccomp',(1024 + 329))
__NR_pkey_mprotect = Constant('__NR_pkey_mprotect',(1024 + 330))
__NR_pkey_alloc = Constant('__NR_pkey_alloc',(1024 + 331))
__NR_pkey_free = Constant('__NR_pkey_free',(1024 + 332))
__NR_rseq = Constant('__NR_rseq',(1024 + 333))
__NR_pidfd_send_signal = Constant('__NR_pidfd_send_signal',(1024 + 424))
__NR_io_uring_setup = Constant('__NR_io_uring_setup',(1024 + 425))
__NR_io_uring_enter = Constant('__NR_io_uring_enter',(1024 + 426))
__NR_io_uring_register = Constant('__NR_io_uring_register',(1024 + 427))
__NR_open_tree = Constant('__NR_open_tree',(1024 + 428))
__NR_move_mount = Constant('__NR_move_mount',(1024 + 429))
__NR_fsopen = Constant('__NR_fsopen',(1024 + 430))
__NR_fsconfig = Constant('__NR_fsconfig',(1024 + 431))
__NR_fsmount = Constant('__NR_fsmount',(1024 + 432))
__NR_fspick = Constant('__NR_fspick',(1024 + 433))
__NR_pidfd_open = Constant('__NR_pidfd_open',(1024 + 434))
__NR_openat2 = Constant('__NR_openat2',(1024 + 437))
__NR_pidfd_getfd = Constant('__NR_pidfd_getfd',(1024 + 438))
MAP_32BIT = Constant('MAP_32BIT',0x40)
INADDR_ANY = Constant('INADDR_ANY',0)
INADDR_BROADCAST = Constant('INADDR_BROADCAST',0xffffffff)
INADDR_NONE = Constant('INADDR_NONE',0xffffffff)
INADDR_LOOPBACK = Constant('INADDR_LOOPBACK',0x7f000001)
EPERM = Constant('EPERM',1)
ENOENT = Constant('ENOENT',2)
ESRCH = Constant('ESRCH',3)
EINTR = Constant('EINTR',4)
EIO = Constant('EIO',5)
ENXIO = Constant('ENXIO',6)
E2BIG = Constant('E2BIG',7)
ENOEXEC = Constant('ENOEXEC',8)
EBADF = Constant('EBADF',9)
ECHILD = Constant('ECHILD',10)
EAGAIN = Constant('EAGAIN',11)
ENOMEM = Constant('ENOMEM',12)
EACCES = Constant('EACCES',13)
EFAULT = Constant('EFAULT',14)
ENOTBLK = Constant('ENOTBLK',15)
EBUSY = Constant('EBUSY',16)
EEXIST = Constant('EEXIST',17)
EXDEV = Constant('EXDEV',18)
ENODEV = Constant('ENODEV',19)
ENOTDIR = Constant('ENOTDIR',20)
EISDIR = Constant('EISDIR',21)
EINVAL = Constant('EINVAL',22)
ENFILE = Constant('ENFILE',23)
EMFILE = Constant('EMFILE',24)
ENOTTY = Constant('ENOTTY',25)
ETXTBSY = Constant('ETXTBSY',26)
EFBIG = Constant('EFBIG',27)
ENOSPC = Constant('ENOSPC',28)
ESPIPE = Constant('ESPIPE',29)
EROFS = Constant('EROFS',30)
EMLINK = Constant('EMLINK',31)
EPIPE = Constant('EPIPE',32)
EDOM = Constant('EDOM',33)
ERANGE = Constant('ERANGE',34)
EDEADLK = Constant('EDEADLK',35)
ENAMETOOLONG = Constant('ENAMETOOLONG',36)
ENOLCK = Constant('ENOLCK',37)
ENOSYS = Constant('ENOSYS',38)
ENOTEMPTY = Constant('ENOTEMPTY',39)
ELOOP = Constant('ELOOP',40)
EWOULDBLOCK = Constant('EWOULDBLOCK',11)
ENOMSG = Constant('ENOMSG',42)
EIDRM = Constant('EIDRM',43)
ECHRNG = Constant('ECHRNG',44)
EL2NSYNC = Constant('EL2NSYNC',45)
EL3HLT = Constant('EL3HLT',46)
EL3RST = Constant('EL3RST',47)
ELNRNG = Constant('ELNRNG',48)
EUNATCH = Constant('EUNATCH',49)
ENOCSI = Constant('ENOCSI',50)
EL2HLT = Constant('EL2HLT',51)
EBADE = Constant('EBADE',52)
EBADR = Constant('EBADR',53)
EXFULL = Constant('EXFULL',54)
ENOANO = Constant('ENOANO',55)
EBADRQC = Constant('EBADRQC',56)
EBADSLT = Constant('EBADSLT',57)
EDEADLOCK = Constant('EDEADLOCK',35)
EBFONT = Constant('EBFONT',59)
ENOSTR = Constant('ENOSTR',60)
ENODATA = Constant('ENODATA',61)
ETIME = Constant('ETIME',62)
ENOSR = Constant('ENOSR',63)
ENONET = Constant('ENONET',64)
ENOPKG = Constant('ENOPKG',65)
EREMOTE = Constant('EREMOTE',66)
ENOLINK = Constant('ENOLINK',67)
EADV = Constant('EADV',68)
ESRMNT = Constant('ESRMNT',69)
ECOMM = Constant('ECOMM',70)
EPROTO = Constant('EPROTO',71)
EMULTIHOP = Constant('EMULTIHOP',72)
EDOTDOT = Constant('EDOTDOT',73)
EBADMSG = Constant('EBADMSG',74)
EOVERFLOW = Constant('EOVERFLOW',75)
ENOTUNIQ = Constant('ENOTUNIQ',76)
EBADFD = Constant('EBADFD',77)
EREMCHG = Constant('EREMCHG',78)
ELIBACC = Constant('ELIBACC',79)
ELIBBAD = Constant('ELIBBAD',80)
ELIBSCN = Constant('ELIBSCN',81)
ELIBMAX = Constant('ELIBMAX',82)
ELIBEXEC = Constant('ELIBEXEC',83)
EILSEQ = Constant('EILSEQ',84)
ERESTART = Constant('ERESTART',85)
ESTRPIPE = Constant('ESTRPIPE',86)
EUSERS = Constant('EUSERS',87)
ENOTSOCK = Constant('ENOTSOCK',88)
EDESTADDRREQ = Constant('EDESTADDRREQ',89)
EMSGSIZE = Constant('EMSGSIZE',90)
EPROTOTYPE = Constant('EPROTOTYPE',91)
ENOPROTOOPT = Constant('ENOPROTOOPT',92)
EPROTONOSUPPORT = Constant('EPROTONOSUPPORT',93)
ESOCKTNOSUPPORT = Constant('ESOCKTNOSUPPORT',94)
EOPNOTSUPP = Constant('EOPNOTSUPP',95)
ENOTSUP = Constant('ENOTSUP',95)
EPFNOSUPPORT = Constant('EPFNOSUPPORT',96)
EAFNOSUPPORT = Constant('EAFNOSUPPORT',97)
EADDRINUSE = Constant('EADDRINUSE',98)
EADDRNOTAVAIL = Constant('EADDRNOTAVAIL',99)
ENETDOWN = Constant('ENETDOWN',100)
ENETUNREACH = Constant('ENETUNREACH',101)
ENETRESET = Constant('ENETRESET',102)
ECONNABORTED = Constant('ECONNABORTED',103)
ECONNRESET = Constant('ECONNRESET',104)
ENOBUFS = Constant('ENOBUFS',105)
EISCONN = Constant('EISCONN',106)
ENOTCONN = Constant('ENOTCONN',107)
ESHUTDOWN = Constant('ESHUTDOWN',108)
ETOOMANYREFS = Constant('ETOOMANYREFS',109)
ETIMEDOUT = Constant('ETIMEDOUT',110)
ECONNREFUSED = Constant('ECONNREFUSED',111)
EHOSTDOWN = Constant('EHOSTDOWN',112)
EHOSTUNREACH = Constant('EHOSTUNREACH',113)
EALREADY = Constant('EALREADY',114)
EINPROGRESS = Constant('EINPROGRESS',115)
ESTALE = Constant('ESTALE',116)
EUCLEAN = Constant('EUCLEAN',117)
ENOTNAM = Constant('ENOTNAM',118)
ENAVAIL = Constant('ENAVAIL',119)
EISNAM = Constant('EISNAM',120)
EREMOTEIO = Constant('EREMOTEIO',121)
EDQUOT = Constant('EDQUOT',122)
ENOMEDIUM = Constant('ENOMEDIUM',123)
EMEDIUMTYPE = Constant('EMEDIUMTYPE',124)
ECANCELED = Constant('ECANCELED',125)
ENOKEY = Constant('ENOKEY',126)
EKEYEXPIRED = Constant('EKEYEXPIRED',127)
EKEYREVOKED = Constant('EKEYREVOKED',128)
EKEYREJECTED = Constant('EKEYREJECTED',129)
EOWNERDEAD = Constant('EOWNERDEAD',130)
ENOTRECOVERABLE = Constant('ENOTRECOVERABLE',131)
ERFKILL = Constant('ERFKILL',132)
EHWPOISON = Constant('EHWPOISON',133)
__SYS_NERR = Constant('__SYS_NERR',((133) + 1))
__LITTLE_ENDIAN = Constant('__LITTLE_ENDIAN',1234)
__BIG_ENDIAN = Constant('__BIG_ENDIAN',4321)
__BYTE_ORDER = Constant('__BYTE_ORDER',1234)
__FLOAT_WORD_ORDER = Constant('__FLOAT_WORD_ORDER',1234)
LITTLE_ENDIAN = Constant('LITTLE_ENDIAN',1234)
BIG_ENDIAN = Constant('BIG_ENDIAN',4321)
BYTE_ORDER = Constant('BYTE_ORDER',1234)
__WORDSIZE = Constant('__WORDSIZE',64)
INT8_MAX = Constant('INT8_MAX',(127))
INT16_MAX = Constant('INT16_MAX',(32767))
INT32_MAX = Constant('INT32_MAX',(2147483647))
INT64_MAX = Constant('INT64_MAX',(9223372036854775807))
INT8_MIN = Constant('INT8_MIN',(-1 - (127)))
INT16_MIN = Constant('INT16_MIN',(-1 - (32767)))
INT32_MIN = Constant('INT32_MIN',(-1 - (2147483647)))
INT64_MIN = Constant('INT64_MIN',(-1 - (9223372036854775807)))
INT_LEAST8_MAX = Constant('INT_LEAST8_MAX',(127))
INT_LEAST8_MIN = Constant('INT_LEAST8_MIN',(-1 - (127)))
INT_LEAST16_MAX = Constant('INT_LEAST16_MAX',(32767))
INT_LEAST16_MIN = Constant('INT_LEAST16_MIN',(-1 - (32767)))
INT_LEAST32_MAX = Constant('INT_LEAST32_MAX',(2147483647))
INT_LEAST32_MIN = Constant('INT_LEAST32_MIN',(-1 - (2147483647)))
INT_LEAST64_MAX = Constant('INT_LEAST64_MAX',(9223372036854775807))
INT_LEAST64_MIN = Constant('INT_LEAST64_MIN',(-1 - (9223372036854775807)))
UINT8_MAX = Constant('UINT8_MAX',0xff)
UINT16_MAX = Constant('UINT16_MAX',0xffff)
UINT32_MAX = Constant('UINT32_MAX',0xffffffff)
UINT64_MAX = Constant('UINT64_MAX',0xffffffffffffffff)
UINT_LEAST8_MAX = Constant('UINT_LEAST8_MAX',0xff)
UINT_LEAST16_MAX = Constant('UINT_LEAST16_MAX',0xffff)
UINT_LEAST32_MAX = Constant('UINT_LEAST32_MAX',0xffffffff)
UINT_LEAST64_MAX = Constant('UINT_LEAST64_MAX',0xffffffffffffffff)
INTPTR_MIN = Constant('INTPTR_MIN',(-1 - (9223372036854775807)))
INTPTR_MAX = Constant('INTPTR_MAX',(9223372036854775807))
UINTPTR_MAX = Constant('UINTPTR_MAX',0xffffffffffffffff)
SIZE_MAX = Constant('SIZE_MAX',0xffffffffffffffff)
PTRDIFF_MIN = Constant('PTRDIFF_MIN',(-1 - (9223372036854775807)))
PTRDIFF_MAX = Constant('PTRDIFF_MAX',(9223372036854775807))
INTMAX_MIN = Constant('INTMAX_MIN',(-1 - (9223372036854775807)))
INTMAX_MAX = Constant('INTMAX_MAX',(9223372036854775807))
UINTMAX_MAX = Constant('UINTMAX_MAX',0xffffffffffffffff)
INT_FAST8_MIN = Constant('INT_FAST8_MIN',(-1 - (127)))
INT_FAST8_MAX = Constant('INT_FAST8_MAX',(127))
INT_FAST64_MIN = Constant('INT_FAST64_MIN',(-1 - (9223372036854775807)))
INT_FAST64_MAX = Constant('INT_FAST64_MAX',(9223372036854775807))
UINT_FAST8_MAX = Constant('UINT_FAST8_MAX',0xff)
UINT_FAST64_MAX = Constant('UINT_FAST64_MAX',0xffffffffffffffff)
INT_FAST16_MIN = Constant('INT_FAST16_MIN',(-1 - (9223372036854775807)))
INT_FAST16_MAX = Constant('INT_FAST16_MAX',(9223372036854775807))
UINT_FAST16_MAX = Constant('UINT_FAST16_MAX',0xffffffffffffffff)
INT_FAST32_MIN = Constant('INT_FAST32_MIN',(-1 - (9223372036854775807)))
INT_FAST32_MAX = Constant('INT_FAST32_MAX',(9223372036854775807))
UINT_FAST32_MAX = Constant('UINT_FAST32_MAX',0xffffffffffffffff)
WINT_MIN = Constant('WINT_MIN',0)
__FSUID_H = Constant('__FSUID_H',1)
NSIG = Constant('NSIG',32)
_NSIG = Constant('_NSIG',65)
SIGHUP = Constant('SIGHUP',1)
SIGINT = Constant('SIGINT',2)
SIGQUIT = Constant('SIGQUIT',3)
SIGILL = Constant('SIGILL',4)
SIGTRAP = Constant('SIGTRAP',5)
SIGABRT = Constant('SIGABRT',6)
SIGIOT = Constant('SIGIOT',6)
SIGFPE = Constant('SIGFPE',8)
SIGKILL = Constant('SIGKILL',9)
SIGSEGV = Constant('SIGSEGV',11)
SIGPIPE = Constant('SIGPIPE',13)
SIGALRM = Constant('SIGALRM',14)
SIGTERM = Constant('SIGTERM',15)
SIGUNUSED = Constant('SIGUNUSED',31)
SIGBUS = Constant('SIGBUS',7)
SIGUSR1 = Constant('SIGUSR1',10)
SIGUSR2 = Constant('SIGUSR2',12)
SIGSTKFLT = Constant('SIGSTKFLT',16)
SIGCHLD = Constant('SIGCHLD',17)
SIGCONT = Constant('SIGCONT',18)
SIGSTOP = Constant('SIGSTOP',19)
SIGTSTP = Constant('SIGTSTP',20)
SIGTTIN = Constant('SIGTTIN',21)
SIGTTOU = Constant('SIGTTOU',22)
SIGURG = Constant('SIGURG',23)
SIGXCPU = Constant('SIGXCPU',24)
SIGXFSZ = Constant('SIGXFSZ',25)
SIGVTALRM = Constant('SIGVTALRM',26)
SIGPROF = Constant('SIGPROF',27)
SIGWINCH = Constant('SIGWINCH',28)
SIGIO = Constant('SIGIO',29)
SIGPWR = Constant('SIGPWR',30)
SIGSYS = Constant('SIGSYS',31)
SIGCLD = Constant('SIGCLD',17)
SIGPOLL = Constant('SIGPOLL',29)
SIGLOST = Constant('SIGLOST',30)
SIGRTMIN = Constant('SIGRTMIN',32)
SIGRTMAX = Constant('SIGRTMAX',(65-1))
SA_NOCLDSTOP = Constant('SA_NOCLDSTOP',0x00000001)
SA_NOCLDWAIT = Constant('SA_NOCLDWAIT',0x00000002)
SA_SIGINFO = Constant('SA_SIGINFO',0x00000004)
SA_RESTORER = Constant('SA_RESTORER',0x04000000)
SA_ONSTACK = Constant('SA_ONSTACK',0x08000000)
SA_RESTART = Constant('SA_RESTART',0x10000000)
SA_INTERRUPT = Constant('SA_INTERRUPT',0x20000000)
SA_NODEFER = Constant('SA_NODEFER',0x40000000)
SA_RESETHAND = Constant('SA_RESETHAND',0x80000000)
SA_NOMASK = Constant('SA_NOMASK',0x40000000)
SA_ONESHOT = Constant('SA_ONESHOT',0x80000000)
SS_ONSTACK = Constant('SS_ONSTACK',1)
SS_DISABLE = Constant('SS_DISABLE',2)
MINSIGSTKSZ = Constant('MINSIGSTKSZ',2048)
SIGSTKSZ = Constant('SIGSTKSZ',8192)
SIG_BLOCK = Constant('SIG_BLOCK',0)
SIG_UNBLOCK = Constant('SIG_UNBLOCK',1)
SIG_SETMASK = Constant('SIG_SETMASK',2)
SI_MAX_SIZE = Constant('SI_MAX_SIZE',128)
SIGEV_SIGNAL = Constant('SIGEV_SIGNAL',0)
SIGEV_NONE = Constant('SIGEV_NONE',1)
SIGEV_THREAD = Constant('SIGEV_THREAD',2)
SIGEV_THREAD_ID = Constant('SIGEV_THREAD_ID',4)
SIGEV_MAX_SIZE = Constant('SIGEV_MAX_SIZE',64)
_SYS_TIME_H = Constant('_SYS_TIME_H',1)
ITIMER_REAL = Constant('ITIMER_REAL',0)
ITIMER_VIRTUAL = Constant('ITIMER_VIRTUAL',1)
ITIMER_PROF = Constant('ITIMER_PROF',2)
PTRACE_TRACEME = Constant('PTRACE_TRACEME',0)
PTRACE_PEEKTEXT = Constant('PTRACE_PEEKTEXT',1)
PTRACE_PEEKDATA = Constant('PTRACE_PEEKDATA',2)
PTRACE_PEEKUSR = Constant('PTRACE_PEEKUSR',3)
PTRACE_PEEKUSER = Constant('PTRACE_PEEKUSER',3)
PTRACE_POKETEXT = Constant('PTRACE_POKETEXT',4)
PTRACE_POKEDATA = Constant('PTRACE_POKEDATA',5)
PTRACE_POKEUSR = Constant('PTRACE_POKEUSR',6)
PTRACE_POKEUSER = Constant('PTRACE_POKEUSER',6)
PTRACE_CONT = Constant('PTRACE_CONT',7)
PTRACE_KILL = Constant('PTRACE_KILL',8)
PTRACE_SINGLESTEP = Constant('PTRACE_SINGLESTEP',9)
PTRACE_ATTACH = Constant('PTRACE_ATTACH',0x10)
PTRACE_DETACH = Constant('PTRACE_DETACH',0x11)
PTRACE_SYSCALL = Constant('PTRACE_SYSCALL',24)
PTRACE_GETEVENTMSG = Constant('PTRACE_GETEVENTMSG',0x4201)
PTRACE_GETSIGINFO = Constant('PTRACE_GETSIGINFO',0x4202)
PTRACE_SETSIGINFO = Constant('PTRACE_SETSIGINFO',0x4203)
PTRACE_O_TRACESYSGOOD = Constant('PTRACE_O_TRACESYSGOOD',0x00000001)
PTRACE_O_TRACEFORK = Constant('PTRACE_O_TRACEFORK',0x00000002)
PTRACE_O_TRACEVFORK = Constant('PTRACE_O_TRACEVFORK',0x00000004)
PTRACE_O_TRACECLONE = Constant('PTRACE_O_TRACECLONE',0x00000008)
PTRACE_O_TRACEEXEC = Constant('PTRACE_O_TRACEEXEC',0x00000010)
PTRACE_O_TRACEVFORKDONE = Constant('PTRACE_O_TRACEVFORKDONE',0x00000020)
PTRACE_O_TRACEEXIT = Constant('PTRACE_O_TRACEEXIT',0x00000040)
PTRACE_O_MASK = Constant('PTRACE_O_MASK',0x0000007f)
PTRACE_EVENT_FORK = Constant('PTRACE_EVENT_FORK',1)
PTRACE_EVENT_VFORK = Constant('PTRACE_EVENT_VFORK',2)
PTRACE_EVENT_CLONE = Constant('PTRACE_EVENT_CLONE',3)
PTRACE_EVENT_EXEC = Constant('PTRACE_EVENT_EXEC',4)
PTRACE_EVENT_VFORK_DONE = Constant('PTRACE_EVENT_VFORK_DONE',5)
PTRACE_EVENT_EXIT = Constant('PTRACE_EVENT_EXIT',6)
PT_TRACE_ME = Constant('PT_TRACE_ME',0)
PT_READ_I = Constant('PT_READ_I',1)
PT_READ_D = Constant('PT_READ_D',2)
PT_READ_U = Constant('PT_READ_U',3)
PT_WRITE_I = Constant('PT_WRITE_I',4)
PT_WRITE_D = Constant('PT_WRITE_D',5)
PT_WRITE_U = Constant('PT_WRITE_U',6)
PT_CONTINUE = Constant('PT_CONTINUE',7)
PT_KILL = Constant('PT_KILL',8)
PT_STEP = Constant('PT_STEP',9)
PT_ATTACH = Constant('PT_ATTACH',0x10)
PT_DETACH = Constant('PT_DETACH',0x11)
FD_SETSIZE = Constant('FD_SETSIZE',1024)
R_OK = Constant('R_OK',4)
W_OK = Constant('W_OK',2)
X_OK = Constant('X_OK',1)
F_OK = Constant('F_OK',0)
SEEK_SET = Constant('SEEK_SET',0)
SEEK_CUR = Constant('SEEK_CUR',1)
SEEK_END = Constant('SEEK_END',2)
STDIN_FILENO = Constant('STDIN_FILENO',0)
STDOUT_FILENO = Constant('STDOUT_FILENO',1)
STDERR_FILENO = Constant('STDERR_FILENO',2)
_CS_PATH = Constant('_CS_PATH',1)
_SC_CLK_TCK = Constant('_SC_CLK_TCK',1)
_SC_ARG_MAX = Constant('_SC_ARG_MAX',2)
_SC_NGROUPS_MAX = Constant('_SC_NGROUPS_MAX',3)
_SC_OPEN_MAX = Constant('_SC_OPEN_MAX',4)
_SC_PAGESIZE = Constant('_SC_PAGESIZE',5)
_SC_NPROCESSORS_ONLN = Constant('_SC_NPROCESSORS_ONLN',6)
_SC_NPROCESSORS_CONF = Constant('_SC_NPROCESSORS_CONF',6)
_SC_PHYS_PAGES = Constant('_SC_PHYS_PAGES',7)
_SC_GETPW_R_SIZE_MAX = Constant('_SC_GETPW_R_SIZE_MAX',8)
_SC_GETGR_R_SIZE_MAX = Constant('_SC_GETGR_R_SIZE_MAX',9)
_PC_PATH_MAX = Constant('_PC_PATH_MAX',1)
_PC_VDISABLE = Constant('_PC_VDISABLE',2)
L_cuserid = Constant('L_cuserid',17)
_POSIX_VERSION = Constant('_POSIX_VERSION',199506)
F_ULOCK = Constant('F_ULOCK',0)
F_LOCK = Constant('F_LOCK',1)
F_TLOCK = Constant('F_TLOCK',2)
F_TEST = Constant('F_TEST',3)
_POSIX_MAPPED_FILES = Constant('_POSIX_MAPPED_FILES',200809)
S_IFMT = Constant('S_IFMT',0o0170000)
S_IFSOCK = Constant('S_IFSOCK',0o140000)
S_IFLNK = Constant('S_IFLNK',0o120000)
S_IFREG = Constant('S_IFREG',0o100000)
S_IFBLK = Constant('S_IFBLK',0o060000)
S_IFDIR = Constant('S_IFDIR',0o040000)
S_IFCHR = Constant('S_IFCHR',0o020000)
S_IFIFO = Constant('S_IFIFO',0o010000)
S_ISUID = Constant('S_ISUID',0o004000)
S_ISGID = Constant('S_ISGID',0o002000)
S_ISVTX = Constant('S_ISVTX',0o001000)
S_IRWXU = Constant('S_IRWXU',0o0700)
S_IRUSR = Constant('S_IRUSR',0o0400)
S_IWUSR = Constant('S_IWUSR',0o0200)
S_IXUSR = Constant('S_IXUSR',0o0100)
S_IRWXG = Constant('S_IRWXG',0o0070)
S_IRGRP = Constant('S_IRGRP',0o0040)
S_IWGRP = Constant('S_IWGRP',0o0020)
S_IXGRP = Constant('S_IXGRP',0o0010)
S_IRWXO = Constant('S_IRWXO',0o0007)
S_IROTH = Constant('S_IROTH',0o0004)
S_IWOTH = Constant('S_IWOTH',0o0002)
S_IXOTH = Constant('S_IXOTH',0o0001)
S_IREAD = Constant('S_IREAD',0o0400)
S_IWRITE = Constant('S_IWRITE',0o0200)
S_IEXEC = Constant('S_IEXEC',0o0100)
_SYS_UIO = Constant('_SYS_UIO',1)
SOL_SOCKET = Constant('SOL_SOCKET',1)
SO_DEBUG = Constant('SO_DEBUG',1)
SO_REUSEADDR = Constant('SO_REUSEADDR',2)
SO_TYPE = Constant('SO_TYPE',3)
SO_ERROR = Constant('SO_ERROR',4)
SO_DONTROUTE = Constant('SO_DONTROUTE',5)
SO_BROADCAST = Constant('SO_BROADCAST',6)
SO_SNDBUF = Constant('SO_SNDBUF',7)
SO_RCVBUF = Constant('SO_RCVBUF',8)
SO_KEEPALIVE = Constant('SO_KEEPALIVE',9)
SO_OOBINLINE = Constant('SO_OOBINLINE',10)
SO_NO_CHECK = Constant('SO_NO_CHECK',11)
SO_PRIORITY = Constant('SO_PRIORITY',12)
SO_LINGER = Constant('SO_LINGER',13)
SO_BSDCOMPAT = Constant('SO_BSDCOMPAT',14)
SO_REUSEPORT = Constant('SO_REUSEPORT',15)
SO_PASSCRED = Constant('SO_PASSCRED',16)
SO_PEERCRED = Constant('SO_PEERCRED',17)
SO_RCVLOWAT = Constant('SO_RCVLOWAT',18)
SO_SNDLOWAT = Constant('SO_SNDLOWAT',19)
SO_RCVTIMEO = Constant('SO_RCVTIMEO',20)
SO_SNDTIMEO = Constant('SO_SNDTIMEO',21)
SO_SECURITY_AUTHENTICATION = Constant('SO_SECURITY_AUTHENTICATION',22)
SO_SECURITY_ENCRYPTION_TRANSPORT = Constant('SO_SECURITY_ENCRYPTION_TRANSPORT',23)
SO_SECURITY_ENCRYPTION_NETWORK = Constant('SO_SECURITY_ENCRYPTION_NETWORK',24)
SO_BINDTODEVICE = Constant('SO_BINDTODEVICE',25)
SO_ATTACH_FILTER = Constant('SO_ATTACH_FILTER',26)
SO_DETACH_FILTER = Constant('SO_DETACH_FILTER',27)
SO_GET_FILTER = Constant('SO_GET_FILTER',26)
SO_PEERNAME = Constant('SO_PEERNAME',28)
SO_TIMESTAMP = Constant('SO_TIMESTAMP',29)
SCM_TIMESTAMP = Constant('SCM_TIMESTAMP',29)
SO_ACCEPTCONN = Constant('SO_ACCEPTCONN',30)
SO_PEERSEC = Constant('SO_PEERSEC',31)
SO_SNDBUFFORCE = Constant('SO_SNDBUFFORCE',32)
SO_RCVBUFFORCE = Constant('SO_RCVBUFFORCE',33)
SO_PASSSEC = Constant('SO_PASSSEC',34)
SO_TIMESTAMPNS = Constant('SO_TIMESTAMPNS',35)
SCM_TIMESTAMPNS = Constant('SCM_TIMESTAMPNS',35)
SO_MARK = Constant('SO_MARK',36)
SO_TIMESTAMPING = Constant('SO_TIMESTAMPING',37)
SCM_TIMESTAMPING = Constant('SCM_TIMESTAMPING',37)
SO_PROTOCOL = Constant('SO_PROTOCOL',38)
SO_DOMAIN = Constant('SO_DOMAIN',39)
SO_RXQ_OVFL = Constant('SO_RXQ_OVFL',40)
SO_WIFI_STATUS = Constant('SO_WIFI_STATUS',41)
SCM_WIFI_STATUS = Constant('SCM_WIFI_STATUS',41)
SO_PEEK_OFF = Constant('SO_PEEK_OFF',42)
SO_NOFCS = Constant('SO_NOFCS',43)
SO_LOCK_FILTER = Constant('SO_LOCK_FILTER',44)
SO_SELECT_ERR_QUEUE = Constant('SO_SELECT_ERR_QUEUE',45)
SO_BUSY_POLL = Constant('SO_BUSY_POLL',46)
SO_MAX_PACING_RATE = Constant('SO_MAX_PACING_RATE',47)
SO_BPF_EXTENSIONS = Constant('SO_BPF_EXTENSIONS',48)
SO_INCOMING_CPU = Constant('SO_INCOMING_CPU',49)
SO_ATTACH_BPF = Constant('SO_ATTACH_BPF',50)
SO_DETACH_BPF = Constant('SO_DETACH_BPF',27)
SO_ATTACH_REUSEPORT_CBPF = Constant('SO_ATTACH_REUSEPORT_CBPF',51)
SO_ATTACH_REUSEPORT_EBPF = Constant('SO_ATTACH_REUSEPORT_EBPF',52)
SO_CNX_ADVICE = Constant('SO_CNX_ADVICE',53)
SCM_TIMESTAMPING_OPT_STATS = Constant('SCM_TIMESTAMPING_OPT_STATS',54)
SO_MEMINFO = Constant('SO_MEMINFO',55)
SO_INCOMING_NAPI_ID = Constant('SO_INCOMING_NAPI_ID',56)
SO_COOKIE = Constant('SO_COOKIE',57)
SCM_TIMESTAMPING_PKTINFO = Constant('SCM_TIMESTAMPING_PKTINFO',58)
SO_PEERGROUPS = Constant('SO_PEERGROUPS',59)
SO_ZEROCOPY = Constant('SO_ZEROCOPY',60)
SOCK_STREAM = Constant('SOCK_STREAM',1)
SOCK_DGRAM = Constant('SOCK_DGRAM',2)
SOCK_RAW = Constant('SOCK_RAW',3)
SOCK_RDM = Constant('SOCK_RDM',4)
SOCK_SEQPACKET = Constant('SOCK_SEQPACKET',5)
SOCK_DCCP = Constant('SOCK_DCCP',6)
SOCK_PACKET = Constant('SOCK_PACKET',10)
UIO_FASTIOV = Constant('UIO_FASTIOV',8)
UIO_MAXIOV = Constant('UIO_MAXIOV',1024)
SCM_RIGHTS = Constant('SCM_RIGHTS',0x01)
SCM_CREDENTIALS = Constant('SCM_CREDENTIALS',0x02)
SCM_CONNECT = Constant('SCM_CONNECT',0x03)
AF_UNSPEC = Constant('AF_UNSPEC',0)
AF_UNIX = Constant('AF_UNIX',1)
AF_LOCAL = Constant('AF_LOCAL',1)
AF_INET = Constant('AF_INET',2)
AF_AX25 = Constant('AF_AX25',3)
AF_IPX = Constant('AF_IPX',4)
AF_APPLETALK = Constant('AF_APPLETALK',5)
AF_NETROM = Constant('AF_NETROM',6)
AF_BRIDGE = Constant('AF_BRIDGE',7)
AF_ATMPVC = Constant('AF_ATMPVC',8)
AF_X25 = Constant('AF_X25',9)
AF_INET6 = Constant('AF_INET6',10)
AF_ROSE = Constant('AF_ROSE',11)
AF_DECnet = Constant('AF_DECnet',12)
AF_NETBEUI = Constant('AF_NETBEUI',13)
AF_SECURITY = Constant('AF_SECURITY',14)
AF_KEY = Constant('AF_KEY',15)
AF_NETLINK = Constant('AF_NETLINK',16)
AF_ROUTE = Constant('AF_ROUTE',16)
AF_PACKET = Constant('AF_PACKET',17)
AF_ASH = Constant('AF_ASH',18)
AF_ECONET = Constant('AF_ECONET',19)
AF_ATMSVC = Constant('AF_ATMSVC',20)
AF_SNA = Constant('AF_SNA',22)
AF_IRDA = Constant('AF_IRDA',23)
AF_PPPOX = Constant('AF_PPPOX',24)
AF_WANPIPE = Constant('AF_WANPIPE',25)
AF_LLC = Constant('AF_LLC',26)
AF_IB = Constant('AF_IB',27)
AF_MPLS = Constant('AF_MPLS',28)
AF_CAN = Constant('AF_CAN',29)
AF_TIPC = Constant('AF_TIPC',30)
AF_BLUETOOTH = Constant('AF_BLUETOOTH',31)
AF_IUCV = Constant('AF_IUCV',32)
AF_RXRPC = Constant('AF_RXRPC',33)
AF_ISDN = Constant('AF_ISDN',34)
AF_PHONET = Constant('AF_PHONET',35)
AF_IEEE802154 = Constant('AF_IEEE802154',36)
AF_CAIF = Constant('AF_CAIF',37)
AF_ALG = Constant('AF_ALG',38)
AF_NFC = Constant('AF_NFC',39)
AF_VSOCK = Constant('AF_VSOCK',40)
AF_KCM = Constant('AF_KCM',41)
AF_QIPCRTR = Constant('AF_QIPCRTR',42)
AF_SMC = Constant('AF_SMC',43)
AF_MAX = Constant('AF_MAX',44)
PF_UNSPEC = Constant('PF_UNSPEC',0)
PF_UNIX = Constant('PF_UNIX',1)
PF_LOCAL = Constant('PF_LOCAL',1)
PF_INET = Constant('PF_INET',2)
PF_AX25 = Constant('PF_AX25',3)
PF_IPX = Constant('PF_IPX',4)
PF_APPLETALK = Constant('PF_APPLETALK',5)
PF_NETROM = Constant('PF_NETROM',6)
PF_BRIDGE = Constant('PF_BRIDGE',7)
PF_ATMPVC = Constant('PF_ATMPVC',8)
PF_X25 = Constant('PF_X25',9)
PF_INET6 = Constant('PF_INET6',10)
PF_ROSE = Constant('PF_ROSE',11)
PF_DECnet = Constant('PF_DECnet',12)
PF_NETBEUI = Constant('PF_NETBEUI',13)
PF_SECURITY = Constant('PF_SECURITY',14)
PF_KEY = Constant('PF_KEY',15)
PF_NETLINK = Constant('PF_NETLINK',16)
PF_ROUTE = Constant('PF_ROUTE',16)
PF_PACKET = Constant('PF_PACKET',17)
PF_ASH = Constant('PF_ASH',18)
PF_ECONET = Constant('PF_ECONET',19)
PF_ATMSVC = Constant('PF_ATMSVC',20)
PF_SNA = Constant('PF_SNA',22)
PF_IRDA = Constant('PF_IRDA',23)
PF_PPPOX = Constant('PF_PPPOX',24)
PF_WANPIPE = Constant('PF_WANPIPE',25)
PF_LLC = Constant('PF_LLC',26)
PF_IB = Constant('PF_IB',27)
PF_MPLS = Constant('PF_MPLS',28)
PF_CAN = Constant('PF_CAN',29)
PF_TIPC = Constant('PF_TIPC',30)
PF_BLUETOOTH = Constant('PF_BLUETOOTH',31)
PF_IUCV = Constant('PF_IUCV',32)
PF_RXRPC = Constant('PF_RXRPC',33)
PF_ISDN = Constant('PF_ISDN',34)
PF_PHONET = Constant('PF_PHONET',35)
PF_IEEE802154 = Constant('PF_IEEE802154',36)
PF_CAIF = Constant('PF_CAIF',37)
PF_ALG = Constant('PF_ALG',38)
PF_NFC = Constant('PF_NFC',39)
PF_VSOCK = Constant('PF_VSOCK',40)
PF_KCM = Constant('PF_KCM',41)
PF_QIPCRTR = Constant('PF_QIPCRTR',42)
PF_SMC = Constant('PF_SMC',43)
PF_MAX = Constant('PF_MAX',44)
SOMAXCONN = Constant('SOMAXCONN',128)
MSG_OOB = Constant('MSG_OOB',1)
MSG_PEEK = Constant('MSG_PEEK',2)
MSG_DONTROUTE = Constant('MSG_DONTROUTE',4)
MSG_TRYHARD = Constant('MSG_TRYHARD',4)
MSG_CTRUNC = Constant('MSG_CTRUNC',8)
MSG_PROBE = Constant('MSG_PROBE',0x10)
MSG_TRUNC = Constant('MSG_TRUNC',0x20)
MSG_DONTWAIT = Constant('MSG_DONTWAIT',0x40)
MSG_EOR = Constant('MSG_EOR',0x80)
MSG_WAITALL = Constant('MSG_WAITALL',0x100)
MSG_FIN = Constant('MSG_FIN',0x200)
MSG_SYN = Constant('MSG_SYN',0x400)
MSG_CONFIRM = Constant('MSG_CONFIRM',0x800)
MSG_RST = Constant('MSG_RST',0x1000)
MSG_ERRQUEUE = Constant('MSG_ERRQUEUE',0x2000)
MSG_NOSIGNAL = Constant('MSG_NOSIGNAL',0x4000)
MSG_MORE = Constant('MSG_MORE',0x8000)
MSG_WAITFORONE = Constant('MSG_WAITFORONE',0x10000)
MSG_SENDPAGE_NOTLAST = Constant('MSG_SENDPAGE_NOTLAST',0x20000)
MSG_BATCH = Constant('MSG_BATCH',0x40000)
MSG_EOF = Constant('MSG_EOF',0x200)
MSG_ZEROCOPY = Constant('MSG_ZEROCOPY',0x4000000)
MSG_FASTOPEN = Constant('MSG_FASTOPEN',0x20000000)
MSG_CMSG_CLOEXEC = Constant('MSG_CMSG_CLOEXEC',0x40000000)
SOL_IP = Constant('SOL_IP',0)
SOL_TCP = Constant('SOL_TCP',6)
SOL_UDP = Constant('SOL_UDP',17)
SOL_IPV6 = Constant('SOL_IPV6',41)
SOL_ICMPV6 = Constant('SOL_ICMPV6',58)
SOL_SCTP = Constant('SOL_SCTP',132)
SOL_UDPLITE = Constant('SOL_UDPLITE',136)
SOL_RAW = Constant('SOL_RAW',255)
SOL_IPX = Constant('SOL_IPX',256)
SOL_AX25 = Constant('SOL_AX25',257)
SOL_ATALK = Constant('SOL_ATALK',258)
SOL_NETROM = Constant('SOL_NETROM',259)
SOL_ROSE = Constant('SOL_ROSE',260)
SOL_DECNET = Constant('SOL_DECNET',261)
SOL_X25 = Constant('SOL_X25',262)
SOL_PACKET = Constant('SOL_PACKET',263)
SOL_ATM = Constant('SOL_ATM',264)
SOL_AAL = Constant('SOL_AAL',265)
SOL_IRDA = Constant('SOL_IRDA',266)
SOL_NETBEUI = Constant('SOL_NETBEUI',267)
SOL_LLC = Constant('SOL_LLC',268)
SOL_DCCP = Constant('SOL_DCCP',269)
SOL_NETLINK = Constant('SOL_NETLINK',270)
SOL_TIPC = Constant('SOL_TIPC',271)
SOL_RXRPC = Constant('SOL_RXRPC',272)
SOL_PPPOL2TP = Constant('SOL_PPPOL2TP',273)
SOL_BLUETOOTH = Constant('SOL_BLUETOOTH',274)
SOL_PNPIPE = Constant('SOL_PNPIPE',275)
SOL_RDS = Constant('SOL_RDS',276)
SOL_IUCV = Constant('SOL_IUCV',277)
SOL_CAIF = Constant('SOL_CAIF',278)
SOL_ALG = Constant('SOL_ALG',279)
SOL_NFC = Constant('SOL_NFC',280)
SOL_KCM = Constant('SOL_KCM',281)
SOL_TLS = Constant('SOL_TLS',282)
IPX_TYPE = Constant('IPX_TYPE',1)
SHUT_RD = Constant('SHUT_RD',0)
SHUT_WR = Constant('SHUT_WR',1)
SHUT_RDWR = Constant('SHUT_RDWR',2)
NI_NOFQDN = Constant('NI_NOFQDN',1)
NI_NUMERICHOST = Constant('NI_NUMERICHOST',2)
NI_NAMEREQD = Constant('NI_NAMEREQD',4)
NI_NUMERICSERV = Constant('NI_NUMERICSERV',8)
NI_DGRAM = Constant('NI_DGRAM',16)
EAI_FAMILY = Constant('EAI_FAMILY',-1)
EAI_SOCKTYPE = Constant('EAI_SOCKTYPE',-2)
EAI_BADFLAGS = Constant('EAI_BADFLAGS',-3)
EAI_NONAME = Constant('EAI_NONAME',-4)
EAI_SERVICE = Constant('EAI_SERVICE',-5)
EAI_ADDRFAMILY = Constant('EAI_ADDRFAMILY',-6)
EAI_NODATA = Constant('EAI_NODATA',-7)
EAI_MEMORY = Constant('EAI_MEMORY',-8)
EAI_FAIL = Constant('EAI_FAIL',-9)
EAI_AGAIN = Constant('EAI_AGAIN',-10)
EAI_SYSTEM = Constant('EAI_SYSTEM',-11)
AI_NUMERICHOST = Constant('AI_NUMERICHOST',1)
AI_CANONNAME = Constant('AI_CANONNAME',2)
AI_PASSIVE = Constant('AI_PASSIVE',4)
AI_NUMERICSERV = Constant('AI_NUMERICSERV',8)
AI_ADDRCONFIG = Constant('AI_ADDRCONFIG',16)
AI_V4MAPPED = Constant('AI_V4MAPPED',32)
AI_ALL = Constant('AI_ALL',64)
SIOCADDRT = Constant('SIOCADDRT',0x890B)
SIOCDELRT = Constant('SIOCDELRT',0x890C)
SIOCRTMSG = Constant('SIOCRTMSG',0x890D)
SIOCGIFNAME = Constant('SIOCGIFNAME',0x8910)
SIOCSIFLINK = Constant('SIOCSIFLINK',0x8911)
SIOCGIFCONF = Constant('SIOCGIFCONF',0x8912)
SIOCGIFFLAGS = Constant('SIOCGIFFLAGS',0x8913)
SIOCSIFFLAGS = Constant('SIOCSIFFLAGS',0x8914)
SIOCGIFADDR = Constant('SIOCGIFADDR',0x8915)
SIOCSIFADDR = Constant('SIOCSIFADDR',0x8916)
SIOCGIFDSTADDR = Constant('SIOCGIFDSTADDR',0x8917)
SIOCSIFDSTADDR = Constant('SIOCSIFDSTADDR',0x8918)
SIOCGIFBRDADDR = Constant('SIOCGIFBRDADDR',0x8919)
SIOCSIFBRDADDR = Constant('SIOCSIFBRDADDR',0x891a)
SIOCGIFNETMASK = Constant('SIOCGIFNETMASK',0x891b)
SIOCSIFNETMASK = Constant('SIOCSIFNETMASK',0x891c)
SIOCGIFMETRIC = Constant('SIOCGIFMETRIC',0x891d)
SIOCSIFMETRIC = Constant('SIOCSIFMETRIC',0x891e)
SIOCGIFMEM = Constant('SIOCGIFMEM',0x891f)
SIOCSIFMEM = Constant('SIOCSIFMEM',0x8920)
SIOCGIFMTU = Constant('SIOCGIFMTU',0x8921)
SIOCSIFMTU = Constant('SIOCSIFMTU',0x8922)
SIOCSIFNAME = Constant('SIOCSIFNAME',0x8923)
SIOCSIFHWADDR = Constant('SIOCSIFHWADDR',0x8924)
SIOCGIFENCAP = Constant('SIOCGIFENCAP',0x8925)
SIOCSIFENCAP = Constant('SIOCSIFENCAP',0x8926)
SIOCGIFHWADDR = Constant('SIOCGIFHWADDR',0x8927)
SIOCGIFSLAVE = Constant('SIOCGIFSLAVE',0x8929)
SIOCSIFSLAVE = Constant('SIOCSIFSLAVE',0x8930)
SIOCADDMULTI = Constant('SIOCADDMULTI',0x8931)
SIOCDELMULTI = Constant('SIOCDELMULTI',0x8932)
SIOCGIFINDEX = Constant('SIOCGIFINDEX',0x8933)
SIOGIFINDEX = Constant('SIOGIFINDEX',0x8933)
SIOCSIFPFLAGS = Constant('SIOCSIFPFLAGS',0x8934)
SIOCGIFPFLAGS = Constant('SIOCGIFPFLAGS',0x8935)
SIOCDIFADDR = Constant('SIOCDIFADDR',0x8936)
SIOCSIFHWBROADCAST = Constant('SIOCSIFHWBROADCAST',0x8937)
SIOCGIFCOUNT = Constant('SIOCGIFCOUNT',0x8938)
SIOCGIFBR = Constant('SIOCGIFBR',0x8940)
SIOCSIFBR = Constant('SIOCSIFBR',0x8941)
SIOCGIFTXQLEN = Constant('SIOCGIFTXQLEN',0x8942)
SIOCSIFTXQLEN = Constant('SIOCSIFTXQLEN',0x8943)
SIOCGIFDIVERT = Constant('SIOCGIFDIVERT',0x8944)
SIOCSIFDIVERT = Constant('SIOCSIFDIVERT',0x8945)
SIOCETHTOOL = Constant('SIOCETHTOOL',0x8946)
SIOCDARP = Constant('SIOCDARP',0x8953)
SIOCGARP = Constant('SIOCGARP',0x8954)
SIOCSARP = Constant('SIOCSARP',0x8955)
SIOCDRARP = Constant('SIOCDRARP',0x8960)
SIOCGRARP = Constant('SIOCGRARP',0x8961)
SIOCSRARP = Constant('SIOCSRARP',0x8962)
SIOCGIFMAP = Constant('SIOCGIFMAP',0x8970)
SIOCSIFMAP = Constant('SIOCSIFMAP',0x8971)
SIOCADDDLCI = Constant('SIOCADDDLCI',0x8980)
SIOCDELDLCI = Constant('SIOCDELDLCI',0x8981)
SIOCDEVPRIVATE = Constant('SIOCDEVPRIVATE',0x89F0)
F_LINUX_SPECIFIC_BASE = Constant('F_LINUX_SPECIFIC_BASE',1024)
O_ACCMODE = Constant('O_ACCMODE',0o003)
O_RDONLY = Constant('O_RDONLY',0o0)
O_WRONLY = Constant('O_WRONLY',0o1)
O_RDWR = Constant('O_RDWR',0o2)
O_CREAT = Constant('O_CREAT',0o100)
O_EXCL = Constant('O_EXCL',0o200)
O_NOCTTY = Constant('O_NOCTTY',0o400)
O_TRUNC = Constant('O_TRUNC',0o1000)
O_APPEND = Constant('O_APPEND',0o2000)
O_NONBLOCK = Constant('O_NONBLOCK',0o4000)
O_NDELAY = Constant('O_NDELAY',0o4000)
O_DSYNC = Constant('O_DSYNC',0o10000)
FASYNC = Constant('FASYNC',0o20000)
O_DIRECT = Constant('O_DIRECT',0o40000)
O_LARGEFILE = Constant('O_LARGEFILE',0o100000)
O_DIRECTORY = Constant('O_DIRECTORY',0o200000)
O_NOFOLLOW = Constant('O_NOFOLLOW',0o400000)
O_NOATIME = Constant('O_NOATIME',0o1000000)
O_CLOEXEC = Constant('O_CLOEXEC',0o2000000)
O_SYNC = Constant('O_SYNC',(0o10000|0o4000000))
O_PATH = Constant('O_PATH',0o10000000)
__O_TMPFILE = Constant('__O_TMPFILE',0o20000000)
F_DUPFD = Constant('F_DUPFD',0)
F_GETFD = Constant('F_GETFD',1)
F_SETFD = Constant('F_SETFD',2)
F_GETFL = Constant('F_GETFL',3)
F_SETFL = Constant('F_SETFL',4)
F_GETLK = Constant('F_GETLK',5)
F_SETLK = Constant('F_SETLK',6)
F_SETLKW = Constant('F_SETLKW',7)
F_SETOWN = Constant('F_SETOWN',8)
F_GETOWN = Constant('F_GETOWN',9)
F_SETSIG = Constant('F_SETSIG',10)
F_GETSIG = Constant('F_GETSIG',11)
F_GETLK64 = Constant('F_GETLK64',12)
F_SETLK64 = Constant('F_SETLK64',13)
F_SETLKW64 = Constant('F_SETLKW64',14)
FD_CLOEXEC = Constant('FD_CLOEXEC',1)
F_RDLCK = Constant('F_RDLCK',0)
F_WRLCK = Constant('F_WRLCK',1)
F_UNLCK = Constant('F_UNLCK',2)
F_EXLCK = Constant('F_EXLCK',4)
F_SHLCK = Constant('F_SHLCK',8)
F_INPROGRESS = Constant('F_INPROGRESS',16)
LOCK_SH = Constant('LOCK_SH',1)
LOCK_EX = Constant('LOCK_EX',2)
LOCK_NB = Constant('LOCK_NB',4)
LOCK_UN = Constant('LOCK_UN',8)
LOCK_MAND = Constant('LOCK_MAND',32)
LOCK_READ = Constant('LOCK_READ',64)
LOCK_WRITE = Constant('LOCK_WRITE',128)
LOCK_RW = Constant('LOCK_RW',192)
O_TMPFILE = Constant('O_TMPFILE',(0o20000000 | 0o200000))
O_ASYNC = Constant('O_ASYNC',0o20000)
F_SETOWN_EX = Constant('F_SETOWN_EX',15)
F_GETOWN_EX = Constant('F_GETOWN_EX',16)
F_GETOWNER_UIDS = Constant('F_GETOWNER_UIDS',17)
F_OFD_GETLK = Constant('F_OFD_GETLK',36)
F_OFD_SETLK = Constant('F_OFD_SETLK',37)
F_OFD_SETLKW = Constant('F_OFD_SETLKW',38)
F_OWNER_TID = Constant('F_OWNER_TID',0)
F_OWNER_PID = Constant('F_OWNER_PID',1)
F_OWNER_PGRP = Constant('F_OWNER_PGRP',2)
AT_FDCWD = Constant('AT_FDCWD',-100)
AT_SYMLINK_NOFOLLOW = Constant('AT_SYMLINK_NOFOLLOW',0x100)
AT_REMOVEDIR = Constant('AT_REMOVEDIR',0x200)
AT_SYMLINK_FOLLOW = Constant('AT_SYMLINK_FOLLOW',0x400)
AT_NO_AUTOMOUNT = Constant('AT_NO_AUTOMOUNT',0x800)
AT_EMPTY_PATH = Constant('AT_EMPTY_PATH',0x1000)
AT_EACCESS = Constant('AT_EACCESS',0x200)
MREMAP_MAYMOVE = Constant('MREMAP_MAYMOVE',1)
MREMAP_FIXED = Constant('MREMAP_FIXED',2)
PROT_READ = Constant('PROT_READ',0x1)
PROT_WRITE = Constant('PROT_WRITE',0x2)
PROT_EXEC = Constant('PROT_EXEC',0x4)
PROT_SEM = Constant('PROT_SEM',0x8)
PROT_NONE = Constant('PROT_NONE',0x0)
PROT_GROWSDOWN = Constant('PROT_GROWSDOWN',0x01000000)
PROT_GROWSUP = Constant('PROT_GROWSUP',0x02000000)
MAP_SHARED = Constant('MAP_SHARED',0x01)
MAP_PRIVATE = Constant('MAP_PRIVATE',0x02)
MAP_TYPE = Constant('MAP_TYPE',0xf)
MADV_REMOVE = Constant('MADV_REMOVE',9)
MADV_DONTFORK = Constant('MADV_DONTFORK',10)
MADV_DOFORK = Constant('MADV_DOFORK',11)
MADV_MERGEABLE = Constant('MADV_MERGEABLE',12)
MADV_UNMERGEABLE = Constant('MADV_UNMERGEABLE',13)
MADV_HUGEPAGE = Constant('MADV_HUGEPAGE',14)
MADV_NOHUGEPAGE = Constant('MADV_NOHUGEPAGE',15)
MADV_DONTDUMP = Constant('MADV_DONTDUMP',16)
MADV_DODUMP = Constant('MADV_DODUMP',17)
MADV_HWPOISON = Constant('MADV_HWPOISON',100)
MADV_SOFT_OFFLINE = Constant('MADV_SOFT_OFFLINE',101)
MLOCK_ONFAULT = Constant('MLOCK_ONFAULT',1)
MAP_FIXED = Constant('MAP_FIXED',0x10)
MAP_ANONYMOUS = Constant('MAP_ANONYMOUS',0x20)
MAP_GROWSDOWN = Constant('MAP_GROWSDOWN',0x0100)
MAP_GROWSUP = Constant('MAP_GROWSUP',0x0200)
MAP_DENYWRITE = Constant('MAP_DENYWRITE',0x0800)
MAP_EXECUTABLE = Constant('MAP_EXECUTABLE',0x1000)
MAP_LOCKED = Constant('MAP_LOCKED',0x2000)
MAP_NORESERVE = Constant('MAP_NORESERVE',0x4000)
MAP_POPULATE = Constant('MAP_POPULATE',0x8000)
MAP_NONBLOCK = Constant('MAP_NONBLOCK',0x10000)
MAP_STACK = Constant('MAP_STACK',0x20000)
MAP_HUGETLB = Constant('MAP_HUGETLB',0x40000)
MS_ASYNC = Constant('MS_ASYNC',1)
MS_INVALIDATE = Constant('MS_INVALIDATE',2)
MS_SYNC = Constant('MS_SYNC',4)
MADV_NORMAL = Constant('MADV_NORMAL',0x0)
MADV_RANDOM = Constant('MADV_RANDOM',0x1)
MADV_SEQUENTIAL = Constant('MADV_SEQUENTIAL',0x2)
MADV_WILLNEED = Constant('MADV_WILLNEED',0x3)
MADV_DONTNEED = Constant('MADV_DONTNEED',0x4)
MAP_ANON = Constant('MAP_ANON',0x20)
MAP_FILE = Constant('MAP_FILE',0)
POSIX_MADV_NORMAL = Constant('POSIX_MADV_NORMAL',0x0)
POSIX_MADV_SEQUENTIAL = Constant('POSIX_MADV_SEQUENTIAL',0x2)
POSIX_MADV_RANDOM = Constant('POSIX_MADV_RANDOM',0x1)
POSIX_MADV_WILLNEED = Constant('POSIX_MADV_WILLNEED',0x3)
POSIX_MADV_DONTNEED = Constant('POSIX_MADV_DONTNEED',0x4)
SYS_accept = Constant('SYS_accept',(1024 + 170))
SYS_accept4 = Constant('SYS_accept4',(1024 + 310))
SYS_access = Constant('SYS_access',(1024 + 25))
SYS_acct = Constant('SYS_acct',(1024 + 40))
SYS_add_key = Constant('SYS_add_key',(1024 + 247))
SYS_adjtimex = Constant('SYS_adjtimex',(1024 + 107))
SYS_afs_syscall = Constant('SYS_afs_syscall',(1024 + 117))
SYS_bdflush = Constant('SYS_bdflush',(1024 + 114))
SYS_bind = Constant('SYS_bind',(1024 + 167))
SYS_bpf = Constant('SYS_bpf',(1024 + 317))
SYS_brk = Constant('SYS_brk',(1024 + 36))
SYS_capget = Constant('SYS_capget',(1024 + 161))
SYS_capset = Constant('SYS_capset',(1024 + 162))
SYS_chdir = Constant('SYS_chdir',(1024 + 10))
SYS_chmod = Constant('SYS_chmod',(1024 + 14))
SYS_chown = Constant('SYS_chown',(1024 + 15))
SYS_chroot = Constant('SYS_chroot',(1024 + 44))
SYS_clock_adjtime = Constant('SYS_clock_adjtime',(1024 + 304))
SYS_clock_getres = Constant('SYS_clock_getres',(1024 + 231))
SYS_clock_gettime = Constant('SYS_clock_gettime',(1024 + 230))
SYS_clock_nanosleep = Constant('SYS_clock_nanosleep',(1024 + 232))
SYS_clock_settime = Constant('SYS_clock_settime',(1024 + 229))
SYS_clone = Constant('SYS_clone',(1024 + 104))
SYS_clone2 = Constant('SYS_clone2',(1024 + 189))
SYS_close = Constant('SYS_close',(1024 + 5))
SYS_connect = Constant('SYS_connect',(1024 + 168))
SYS_copy_file_range = Constant('SYS_copy_file_range',(1024 + 323))
SYS_creat = Constant('SYS_creat',(1024 + 6))
SYS_delete_module = Constant('SYS_delete_module',(1024 + 110))
SYS_dup = Constant('SYS_dup',(1024 + 33))
SYS_dup2 = Constant('SYS_dup2',(1024 + 46))
SYS_dup3 = Constant('SYS_dup3',(1024 + 292))
SYS_epoll_create = Constant('SYS_epoll_create',(1024 + 219))
SYS_epoll_create1 = Constant('SYS_epoll_create1',(1024 + 291))
SYS_epoll_ctl = Constant('SYS_epoll_ctl',(1024 + 220))
SYS_epoll_pwait = Constant('SYS_epoll_pwait',(1024 + 281))
SYS_epoll_wait = Constant('SYS_epoll_wait',(1024 + 221))
SYS_eventfd = Constant('SYS_eventfd',(1024 + 285))
SYS_eventfd2 = Constant('SYS_eventfd2',(1024 + 290))
SYS_execve = Constant('SYS_execve',(1024 + 9))
SYS_execveat = Constant('SYS_execveat',(1024 + 318))
SYS_exit = Constant('SYS_exit',(1024 + 1))
SYS_exit_group = Constant('SYS_exit_group',(1024 + 212))
SYS_faccessat = Constant('SYS_faccessat',(1024 + 269))
SYS_fadvise64 = Constant('SYS_fadvise64',(1024 + 210))
SYS_fallocate = Constant('SYS_fallocate',(1024 + 279))
SYS_fanotify_init = Constant('SYS_fanotify_init',(1024 + 299))
SYS_fanotify_mark = Constant('SYS_fanotify_mark',(1024 + 300))
SYS_fchdir = Constant('SYS_fchdir',(1024 + 11))
SYS_fchmod = Constant('SYS_fchmod',(1024 + 75))
SYS_fchmodat = Constant('SYS_fchmodat',(1024 + 268))
SYS_fchown = Constant('SYS_fchown',(1024 + 76))
SYS_fchownat = Constant('SYS_fchownat',(1024 + 260))
SYS_fcntl = Constant('SYS_fcntl',(1024 + 42))
SYS_fdatasync = Constant('SYS_fdatasync',(1024 + 28))
SYS_fgetxattr = Constant('SYS_fgetxattr',(1024 + 198))
SYS_finit_module = Constant('SYS_finit_module',(1024 + 311))
SYS_flistxattr = Constant('SYS_flistxattr',(1024 + 201))
SYS_flock = Constant('SYS_flock',(1024 + 121))
SYS_fremovexattr = Constant('SYS_fremovexattr',(1024 + 204))
SYS_fsconfig = Constant('SYS_fsconfig',(1024 + 431))
SYS_fsetxattr = Constant('SYS_fsetxattr',(1024 + 195))
SYS_fsmount = Constant('SYS_fsmount',(1024 + 432))
SYS_fsopen = Constant('SYS_fsopen',(1024 + 430))
SYS_fspick = Constant('SYS_fspick',(1024 + 433))
SYS_fstat = Constant('SYS_fstat',(1024 + 188))
SYS_fstatfs = Constant('SYS_fstatfs',(1024 + 80))
SYS_fstatfs64 = Constant('SYS_fstatfs64',(1024 + 233))
SYS_fsync = Constant('SYS_fsync',(1024 + 27))
SYS_ftruncate = Constant('SYS_ftruncate',(1024 + 74))
SYS_futex = Constant('SYS_futex',(1024 + 206))
SYS_futimesat = Constant('SYS_futimesat',(1024 + 261))
SYS_getcpu = Constant('SYS_getcpu',(1024 + 280))
SYS_getcwd = Constant('SYS_getcwd',(1024 + 160))
SYS_getdents = Constant('SYS_getdents',(1024 + 120))
SYS_getdents64 = Constant('SYS_getdents64',(1024 + 190))
SYS_getegid = Constant('SYS_getegid',(1024 + 39))
SYS_geteuid = Constant('SYS_geteuid',(1024 + 23))
SYS_getgid = Constant('SYS_getgid',(1024 + 38))
SYS_getgroups = Constant('SYS_getgroups',(1024 + 53))
SYS_getitimer = Constant('SYS_getitimer',(1024 + 95))
SYS_get_mempolicy = Constant('SYS_get_mempolicy',(1024 + 236))
SYS_getpeername = Constant('SYS_getpeername',(1024 + 172))
SYS_getpgid = Constant('SYS_getpgid',(1024 + 55))
SYS_getpid = Constant('SYS_getpid',(1024 + 17))
SYS_getpmsg = Constant('SYS_getpmsg',(1024 + 164))
SYS_getppid = Constant('SYS_getppid',(1024 + 18))
SYS_getpriority = Constant('SYS_getpriority',(1024 + 77))
SYS_getrandom = Constant('SYS_getrandom',(1024 + 315))
SYS_getresgid = Constant('SYS_getresgid',(1024 + 51))
SYS_getresuid = Constant('SYS_getresuid',(1024 + 49))
SYS_getrlimit = Constant('SYS_getrlimit',(1024 + 61))
SYS_get_robust_list = Constant('SYS_get_robust_list',(1024 + 275))
SYS_getrusage = Constant('SYS_getrusage',(1024 + 62))
SYS_getsid = Constant('SYS_getsid',(1024 + 58))
SYS_getsockname = Constant('SYS_getsockname',(1024 + 171))
SYS_getsockopt = Constant('SYS_getsockopt',(1024 + 180))
SYS_gettid = Constant('SYS_gettid',(1024 + 81))
SYS_gettimeofday = Constant('SYS_gettimeofday',(1024 + 63))
SYS_getuid = Constant('SYS_getuid',(1024 + 22))
SYS_getunwind = Constant('SYS_getunwind',(1024 + 191))
SYS_getxattr = Constant('SYS_getxattr',(1024 + 196))
SYS_init_module = Constant('SYS_init_module',(1024 + 109))
SYS_inotify_add_watch = Constant('SYS_inotify_add_watch',(1024 + 254))
SYS_inotify_init = Constant('SYS_inotify_init',(1024 + 253))
SYS_inotify_init1 = Constant('SYS_inotify_init1',(1024 + 294))
SYS_inotify_rm_watch = Constant('SYS_inotify_rm_watch',(1024 + 255))
SYS_io_cancel = Constant('SYS_io_cancel',(1024 + 218))
SYS_ioctl = Constant('SYS_ioctl',(1024 + 41))
SYS_io_destroy = Constant('SYS_io_destroy',(1024 + 215))
SYS_io_getevents = Constant('SYS_io_getevents',(1024 + 216))
SYS_io_pgetevents = Constant('SYS_io_pgetevents',(1024 + 327))
SYS_ioprio_get = Constant('SYS_ioprio_get',(1024 + 251))
SYS_ioprio_set = Constant('SYS_ioprio_set',(1024 + 250))
SYS_io_setup = Constant('SYS_io_setup',(1024 + 214))
SYS_io_submit = Constant('SYS_io_submit',(1024 + 217))
SYS_io_uring_enter = Constant('SYS_io_uring_enter',(1024 + 426))
SYS_io_uring_register = Constant('SYS_io_uring_register',(1024 + 427))
SYS_io_uring_setup = Constant('SYS_io_uring_setup',(1024 + 425))
SYS_kcmp = Constant('SYS_kcmp',(1024 + 321))
SYS_kexec_load = Constant('SYS_kexec_load',(1024 + 244))
SYS_keyctl = Constant('SYS_keyctl',(1024 + 249))
SYS_kill = Constant('SYS_kill',(1024 + 29))
SYS_lchown = Constant('SYS_lchown',(1024 + 100))
SYS_lgetxattr = Constant('SYS_lgetxattr',(1024 + 197))
SYS_link = Constant('SYS_link',(1024 + 7))
SYS_linkat = Constant('SYS_linkat',(1024 + 265))
SYS_Linux = Constant('SYS_Linux',1024)
SYS_listen = Constant('SYS_listen',(1024 + 169))
SYS_listxattr = Constant('SYS_listxattr',(1024 + 199))
SYS_llistxattr = Constant('SYS_llistxattr',(1024 + 200))
SYS_lookup_dcookie = Constant('SYS_lookup_dcookie',(1024 + 213))
SYS_lremovexattr = Constant('SYS_lremovexattr',(1024 + 203))
SYS_lseek = Constant('SYS_lseek',(1024 + 16))
SYS_lsetxattr = Constant('SYS_lsetxattr',(1024 + 194))
SYS_lstat = Constant('SYS_lstat',(1024 + 187))
SYS_madvise = Constant('SYS_madvise',(1024 + 185))
SYS_mbind = Constant('SYS_mbind',(1024 + 235))
SYS_membarrier = Constant('SYS_membarrier',(1024 + 320))
SYS_memfd_create = Constant('SYS_memfd_create',(1024 + 316))
SYS_migrate_pages = Constant('SYS_migrate_pages',(1024 + 256))
SYS_mincore = Constant('SYS_mincore',(1024 + 184))
SYS_mkdir = Constant('SYS_mkdir',(1024 + 31))
SYS_mkdirat = Constant('SYS_mkdirat',(1024 + 258))
SYS_mknod = Constant('SYS_mknod',(1024 + 13))
SYS_mknodat = Constant('SYS_mknodat',(1024 + 259))
SYS_mlock = Constant('SYS_mlock',(1024 + 129))
SYS_mlock2 = Constant('SYS_mlock2',(1024 + 322))
SYS_mlockall = Constant('SYS_mlockall',(1024 + 130))
SYS_mmap = Constant('SYS_mmap',(1024 + 127))
SYS_mmap2 = Constant('SYS_mmap2',(1024 + 148))
SYS_mount = Constant('SYS_mount',(1024 + 19))
SYS_move_mount = Constant('SYS_move_mount',(1024 + 429))
SYS_move_pages = Constant('SYS_move_pages',(1024 + 252))
SYS_mprotect = Constant('SYS_mprotect',(1024 + 131))
SYS_mq_getsetattr = Constant('SYS_mq_getsetattr',(1024 + 243))
SYS_mq_notify = Constant('SYS_mq_notify',(1024 + 242))
SYS_mq_open = Constant('SYS_mq_open',(1024 + 238))
SYS_mq_timedreceive = Constant('SYS_mq_timedreceive',(1024 + 241))
SYS_mq_timedsend = Constant('SYS_mq_timedsend',(1024 + 240))
SYS_mq_unlink = Constant('SYS_mq_unlink',(1024 + 239))
SYS_mremap = Constant('SYS_mremap',(1024 + 132))
SYS_msgctl = Constant('SYS_msgctl',(1024 + 88))
SYS_msgget = Constant('SYS_msgget',(1024 + 85))
SYS_msgrcv = Constant('SYS_msgrcv',(1024 + 87))
SYS_msgsnd = Constant('SYS_msgsnd',(1024 + 86))
SYS_msync = Constant('SYS_msync',(1024 + 133))
SYS_munlock = Constant('SYS_munlock',(1024 + 134))
SYS_munlockall = Constant('SYS_munlockall',(1024 + 135))
SYS_munmap = Constant('SYS_munmap',(1024 + 128))
SYS_name_to_handle_at = Constant('SYS_name_to_handle_at',(1024 + 302))
SYS_nanosleep = Constant('SYS_nanosleep',(1024 + 144))
SYS_newfstatat = Constant('SYS_newfstatat',(1024 + 262))
SYS_nfsservctl = Constant('SYS_nfsservctl',(1024 + 145))
SYS_ni_syscall = Constant('SYS_ni_syscall',(1024 + 0))
SYS_old_getpagesize = Constant('SYS_old_getpagesize',(1024 + 147))
SYS_open = Constant('SYS_open',(1024 + 4))
SYS_openat = Constant('SYS_openat',(1024 + 257))
SYS_openat2 = Constant('SYS_openat2',(1024 + 437))
SYS_open_by_handle_at = Constant('SYS_open_by_handle_at',(1024 + 303))
SYS_open_tree = Constant('SYS_open_tree',(1024 + 428))
SYS_pciconfig_read = Constant('SYS_pciconfig_read',(1024 + 149))
SYS_pciconfig_write = Constant('SYS_pciconfig_write',(1024 + 150))
SYS_perf_event_open = Constant('SYS_perf_event_open',(1024 + 328))
SYS_perfmonctl = Constant('SYS_perfmonctl',(1024 + 151))
SYS_personality = Constant('SYS_personality',(1024 + 116))
SYS_pidfd_getfd = Constant('SYS_pidfd_getfd',(1024 + 438))
SYS_pidfd_open = Constant('SYS_pidfd_open',(1024 + 434))
SYS_pidfd_send_signal = Constant('SYS_pidfd_send_signal',(1024 + 424))
SYS_pipe = Constant('SYS_pipe',(1024 + 34))
SYS_pipe2 = Constant('SYS_pipe2',(1024 + 293))
SYS_pivot_root = Constant('SYS_pivot_root',(1024 + 183))
SYS_pkey_alloc = Constant('SYS_pkey_alloc',(1024 + 331))
SYS_pkey_free = Constant('SYS_pkey_free',(1024 + 332))
SYS_pkey_mprotect = Constant('SYS_pkey_mprotect',(1024 + 330))
SYS_poll = Constant('SYS_poll',(1024 + 66))
SYS_ppoll = Constant('SYS_ppoll',(1024 + 271))
SYS_prctl = Constant('SYS_prctl',(1024 + 146))
SYS_pread64 = Constant('SYS_pread64',(1024 + 124))
SYS_preadv = Constant('SYS_preadv',(1024 + 295))
SYS_preadv2 = Constant('SYS_preadv2',(1024 + 324))
SYS_prlimit64 = Constant('SYS_prlimit64',(1024 + 301))
SYS_process_vm_readv = Constant('SYS_process_vm_readv',(1024 + 308))
SYS_process_vm_writev = Constant('SYS_process_vm_writev',(1024 + 309))
SYS_pselect6 = Constant('SYS_pselect6',(1024 + 270))
SYS_ptrace = Constant('SYS_ptrace',(1024 + 24))
SYS_putpmsg = Constant('SYS_putpmsg',(1024 + 165))
SYS_pwrite64 = Constant('SYS_pwrite64',(1024 + 125))
SYS_pwritev = Constant('SYS_pwritev',(1024 + 296))
SYS_pwritev2 = Constant('SYS_pwritev2',(1024 + 325))
SYS_quotactl = Constant('SYS_quotactl',(1024 + 113))
SYS_read = Constant('SYS_read',(1024 + 2))
SYS_readahead = Constant('SYS_readahead',(1024 + 192))
SYS_readlink = Constant('SYS_readlink',(1024 + 68))
SYS_readlinkat = Constant('SYS_readlinkat',(1024 + 267))
SYS_readv = Constant('SYS_readv',(1024 + 122))
SYS_reboot = Constant('SYS_reboot',(1024 + 72))
SYS_recv = Constant('SYS_recv',(1024 + 176))
SYS_recvfrom = Constant('SYS_recvfrom',(1024 + 177))
SYS_recvmmsg = Constant('SYS_recvmmsg',(1024 + 298))
SYS_recvmsg = Constant('SYS_recvmsg',(1024 + 182))
SYS_remap_file_pages = Constant('SYS_remap_file_pages',(1024 + 101))
SYS_removexattr = Constant('SYS_removexattr',(1024 + 202))
SYS_rename = Constant('SYS_rename',(1024 + 30))
SYS_renameat = Constant('SYS_renameat',(1024 + 264))
SYS_renameat2 = Constant('SYS_renameat2',(1024 + 314))
SYS_request_key = Constant('SYS_request_key',(1024 + 248))
SYS_restart_syscall = Constant('SYS_restart_syscall',(1024 + 222))
SYS_rmdir = Constant('SYS_rmdir',(1024 + 32))
SYS_rseq = Constant('SYS_rseq',(1024 + 333))
SYS_rt_sigaction = Constant('SYS_rt_sigaction',(1024 + 153))
SYS_rt_sigpending = Constant('SYS_rt_sigpending',(1024 + 154))
SYS_rt_sigprocmask = Constant('SYS_rt_sigprocmask',(1024 + 155))
SYS_rt_sigqueueinfo = Constant('SYS_rt_sigqueueinfo',(1024 + 156))
SYS_rt_sigreturn = Constant('SYS_rt_sigreturn',(1024 + 157))
SYS_rt_sigsuspend = Constant('SYS_rt_sigsuspend',(1024 + 158))
SYS_rt_sigtimedwait = Constant('SYS_rt_sigtimedwait',(1024 + 159))
SYS_rt_tgsigqueueinfo = Constant('SYS_rt_tgsigqueueinfo',(1024 + 297))
SYS_sched_getaffinity = Constant('SYS_sched_getaffinity',(1024 + 208))
SYS_sched_getattr = Constant('SYS_sched_getattr',(1024 + 313))
SYS_sched_getparam = Constant('SYS_sched_getparam',(1024 + 136))
SYS_sched_get_priority_max = Constant('SYS_sched_get_priority_max',(1024 + 141))
SYS_sched_get_priority_min = Constant('SYS_sched_get_priority_min',(1024 + 142))
SYS_sched_getscheduler = Constant('SYS_sched_getscheduler',(1024 + 138))
SYS_sched_rr_get_interval = Constant('SYS_sched_rr_get_interval',(1024 + 143))
SYS_sched_setaffinity = Constant('SYS_sched_setaffinity',(1024 + 207))
SYS_sched_setattr = Constant('SYS_sched_setattr',(1024 + 312))
SYS_sched_setparam = Constant('SYS_sched_setparam',(1024 + 137))
SYS_sched_setscheduler = Constant('SYS_sched_setscheduler',(1024 + 139))
SYS_sched_yield = Constant('SYS_sched_yield',(1024 + 140))
SYS_seccomp = Constant('SYS_seccomp',(1024 + 329))
SYS_select = Constant('SYS_select',(1024 + 65))
SYS_semctl = Constant('SYS_semctl',(1024 + 84))
SYS_semget = Constant('SYS_semget',(1024 + 82))
SYS_semop = Constant('SYS_semop',(1024 + 83))
SYS_semtimedop = Constant('SYS_semtimedop',(1024 + 223))
SYS_send = Constant('SYS_send',(1024 + 174))
SYS_sendfile = Constant('SYS_sendfile',(1024 + 163))
SYS_sendmmsg = Constant('SYS_sendmmsg',(1024 + 307))
SYS_sendmsg = Constant('SYS_sendmsg',(1024 + 181))
SYS_sendto = Constant('SYS_sendto',(1024 + 175))
SYS_setdomainname = Constant('SYS_setdomainname',(1024 + 105))
SYS_setfsgid = Constant('SYS_setfsgid',(1024 + 119))
SYS_setfsuid = Constant('SYS_setfsuid',(1024 + 118))
SYS_setgid = Constant('SYS_setgid',(1024 + 37))
SYS_setgroups = Constant('SYS_setgroups',(1024 + 54))
SYS_sethostname = Constant('SYS_sethostname',(1024 + 59))
SYS_setitimer = Constant('SYS_setitimer',(1024 + 94))
SYS_set_mempolicy = Constant('SYS_set_mempolicy',(1024 + 237))
SYS_setns = Constant('SYS_setns',(1024 + 306))
SYS_setpgid = Constant('SYS_setpgid',(1024 + 56))
SYS_setpriority = Constant('SYS_setpriority',(1024 + 78))
SYS_setregid = Constant('SYS_setregid',(1024 + 48))
SYS_setresgid = Constant('SYS_setresgid',(1024 + 52))
SYS_setresuid = Constant('SYS_setresuid',(1024 + 50))
SYS_setreuid = Constant('SYS_setreuid',(1024 + 47))
SYS_setrlimit = Constant('SYS_setrlimit',(1024 + 60))
SYS_set_robust_list = Constant('SYS_set_robust_list',(1024 + 274))
SYS_setsid = Constant('SYS_setsid',(1024 + 57))
SYS_setsockopt = Constant('SYS_setsockopt',(1024 + 179))
SYS_set_tid_address = Constant('SYS_set_tid_address',(1024 + 209))
SYS_settimeofday = Constant('SYS_settimeofday',(1024 + 64))
SYS_setuid = Constant('SYS_setuid',(1024 + 21))
SYS_setxattr = Constant('SYS_setxattr',(1024 + 193))
SYS_shmat = Constant('SYS_shmat',(1024 + 90))
SYS_shmctl = Constant('SYS_shmctl',(1024 + 92))
SYS_shmdt = Constant('SYS_shmdt',(1024 + 91))
SYS_shmget = Constant('SYS_shmget',(1024 + 89))
SYS_shutdown = Constant('SYS_shutdown',(1024 + 178))
SYS_sigaltstack = Constant('SYS_sigaltstack',(1024 + 152))
SYS_signalfd = Constant('SYS_signalfd',(1024 + 283))
SYS_signalfd4 = Constant('SYS_signalfd4',(1024 + 289))
SYS_socket = Constant('SYS_socket',(1024 + 166))
SYS_socketpair = Constant('SYS_socketpair',(1024 + 173))
SYS_splice = Constant('SYS_splice',(1024 + 273))
SYS_stat = Constant('SYS_stat',(1024 + 186))
SYS_statfs = Constant('SYS_statfs',(1024 + 79))
SYS_statfs64 = Constant('SYS_statfs64',(1024 + 234))
SYS_statx = Constant('SYS_statx',(1024 + 326))
SYS_swapoff = Constant('SYS_swapoff',(1024 + 71))
SYS_swapon = Constant('SYS_swapon',(1024 + 70))
SYS_symlink = Constant('SYS_symlink',(1024 + 67))
SYS_symlinkat = Constant('SYS_symlinkat',(1024 + 266))
SYS_sync = Constant('SYS_sync',(1024 + 26))
SYS_sync_file_range = Constant('SYS_sync_file_range',(1024 + 276))
SYS_syncfs = Constant('SYS_syncfs',(1024 + 305))
SYS__sysctl = Constant('SYS__sysctl',(1024 + 126))
SYS_sysfs = Constant('SYS_sysfs',(1024 + 115))
SYS_sysinfo = Constant('SYS_sysinfo',(1024 + 103))
SYS_syslog = Constant('SYS_syslog',(1024 + 93))
SYS_tee = Constant('SYS_tee',(1024 + 277))
SYS_tgkill = Constant('SYS_tgkill',(1024 + 211))
SYS_timer_create = Constant('SYS_timer_create',(1024 + 224))
SYS_timer_delete = Constant('SYS_timer_delete',(1024 + 228))
SYS_timerfd = Constant('SYS_timerfd',(1024 + 284))
SYS_timerfd_create = Constant('SYS_timerfd_create',(1024 + 286))
SYS_timerfd_gettime = Constant('SYS_timerfd_gettime',(1024 + 288))
SYS_timerfd_settime = Constant('SYS_timerfd_settime',(1024 + 287))
SYS_timer_getoverrun = Constant('SYS_timer_getoverrun',(1024 + 227))
SYS_timer_gettime = Constant('SYS_timer_gettime',(1024 + 226))
SYS_timer_settime = Constant('SYS_timer_settime',(1024 + 225))
SYS_times = Constant('SYS_times',(1024 + 35))
SYS_tkill = Constant('SYS_tkill',(1024 + 205))
SYS_truncate = Constant('SYS_truncate',(1024 + 73))
SYS_umask = Constant('SYS_umask',(1024 + 43))
SYS_umount2 = Constant('SYS_umount2',(1024 + 20))
SYS_uname = Constant('SYS_uname',(1024 + 106))
SYS_unlink = Constant('SYS_unlink',(1024 + 8))
SYS_unlinkat = Constant('SYS_unlinkat',(1024 + 263))
SYS_unshare = Constant('SYS_unshare',(1024 + 272))
SYS_uselib = Constant('SYS_uselib',(1024 + 69))
SYS_userfaultfd = Constant('SYS_userfaultfd',(1024 + 319))
SYS_ustat = Constant('SYS_ustat',(1024 + 45))
SYS_utimensat = Constant('SYS_utimensat',(1024 + 282))
SYS_utimes = Constant('SYS_utimes',(1024 + 12))
SYS_vhangup = Constant('SYS_vhangup',(1024 + 99))
SYS_vmsplice = Constant('SYS_vmsplice',(1024 + 278))
SYS_vserver = Constant('SYS_vserver',(1024 + 245))
SYS_wait4 = Constant('SYS_wait4',(1024 + 102))
SYS_waitid = Constant('SYS_waitid',(1024 + 246))
SYS_write = Constant('SYS_write',(1024 + 3))
SYS_writev = Constant('SYS_writev',(1024 + 123))
